@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/privileges.h>
 #include <client/logic.h>
 #include <filter/roles.h>
-#include <filter/indonesian.h>
 using namespace std;
 
 
@@ -56,34 +55,20 @@ bool read (void * webserver_request, const string & bible, string user)
     role_level = request->database_users ()->get_level (user);
   }
 
-  // Indonesian Cloud Free.
-  if (config::logic::indonesian_cloud_free ()) {
-    // A free guest account has a role of "Consultant".
-    if (role_level == Filter_Roles::consultant()) {
-      // This level/role has access to:
-      // 1. AlkitabKita / Everyone's Translation.
-      if (bible == filter::indonesian::ourtranslation ()) return true;
-      // 2. Terjemahanku <user> (My Translation <user>).
-      else if (bible == filter::indonesian::mytranslation (user)) return true;
-      // If the Bible is none of the above, the free guest account does not have access to it.
-      else return false;
-    }
-  }
-
   // Managers and higher have read access.
   if (role_level >= Filter_Roles::manager ()) {
     return true;
   }
 
   // Read privileges for the user.
-  auto [ read, write ] = Database_Privileges::getBible (user, bible);
+  auto [ read, write ] = DatabasePrivileges::get_bible (user, bible);
   if (read) {
     return true;
   }
 
   // No Bibles assigned: Consultant can view any Bible.
   if (role_level >= Filter_Roles::consultant ()) {
-    if (int privileges_count = Database_Privileges::getBibleBookCount (); privileges_count == 0) {
+    if (int privileges_count = DatabasePrivileges::get_bible_book_count (); privileges_count == 0) {
       return true;
     }
   }
@@ -105,10 +90,6 @@ bool write (void * webserver_request, const string & bible, string user)
     return true;
   }
 #endif
-  // Indonesian Cloud Free: Access all Bibles.
-  if (config::logic::indonesian_cloud_free ()) {
-    return true;
-  }
 
   int level {0};
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
@@ -127,14 +108,14 @@ bool write (void * webserver_request, const string & bible, string user)
   }
   
   // Read the privileges for the user.
-  auto [ read, write ] = Database_Privileges::getBible (user, bible);
+  auto [ read, write ] = DatabasePrivileges::get_bible (user, bible);
   if (write) {
     return true;
   }
   
   // No Bibles assigned: Translator can write to any bible.
   if (level >= Filter_Roles::translator ()) {
-    if (int privileges_count = Database_Privileges::getBibleBookCount (); privileges_count == 0) {
+    if (int privileges_count = DatabasePrivileges::get_bible_book_count (); privileges_count == 0) {
       return true;
     }
   }
@@ -171,19 +152,6 @@ bool book_write (void * webserver_request, string user, const string & bible, in
     level = request->database_users ()->get_level (user);
   }
 
-  // Indonesian Cloud Free.
-  // The free guest account has a role of Consultant.
-  // The consultant has write access to his/her own Bible.
-  // The consultant has read-access to the "AlkitabKita" Bible.
-  if (config::logic::indonesian_cloud_free ()) {
-    if (level == Filter_Roles::consultant()) {
-      if (bible == filter::indonesian::ourtranslation()) {
-        return false;
-      }
-    }
-    return true;
-  }
-
   // Managers and higher always have write access.
   if (level >= Filter_Roles::manager ()) {
     return true;
@@ -192,14 +160,14 @@ bool book_write (void * webserver_request, string user, const string & bible, in
   // Read the privileges for the user.
   bool read {false};
   bool write {false};
-  Database_Privileges::getBibleBook (user, bible, book, read, write);
+  DatabasePrivileges::get_bible_book (user, bible, book, read, write);
   if (write) {
     return true;
   }
 
   // No Bibles assigned: Translator can write to any bible.
   if (level >= Filter_Roles::translator ()) {
-    if (int privileges_count = Database_Privileges::getBibleBookCount (); privileges_count == 0) {
+    if (int privileges_count = DatabasePrivileges::get_bible_book_count (); privileges_count == 0) {
       return true;
     }
   }
@@ -254,17 +222,6 @@ tuple<bool, bool> any (void * webserver_request)
     if (access_bible::read (webserver_request, bible)) read = true;
     if (access_bible::write (webserver_request, bible)) write = true;
   }
-  if (config::logic::indonesian_cloud_free ()) {
-    if (int level = request->session_logic ()->currentLevel ();
-        level >= Filter_Roles::consultant())
-    {
-      read = true;
-      write = true;
-    } else {
-      read = false;
-      write = false;
-    }
-  }
   // The results consists of <read, write>.
   return make_tuple(read, write);
 }
