@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_BIBLE_IMPORT_H
-#define INCLUDED_BIBLE_IMPORT_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string bible_import_url ();
+std::string bible_import_url ();
 bool bible_import_acl (void * webserver_request);
-string bible_import (void * webserver_request);
-
-
-#endif
+std::string bible_import (void * webserver_request);
