@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -36,21 +36,21 @@ void bible_import_run (string location, string bible, int book, int chapter)
 
   string folder = filter_archive_uncompress (location);
   if (!folder.empty ()) location = folder;
-  vector <string> files;
+  vector <string> files {};
   if (filter_url_is_dir (location)) {
     filter_url_recursive_scandir (location, files);
   } else {
     files.push_back (location);
   }
   
-  for (auto & file : files) {
+  for (const auto & file : files) {
     if (filter_url_is_dir (file)) continue;
     Database_Logs::log ("Examining file for import: " + file);
-    string success_message = "";
-    string error_message = "";
+    string success_message {};
+    string error_message {};
     string data = filter_url_file_get_contents (file);
     if (!data.empty()) {
-      if (unicode_string_is_valid (data)) {
+      if (filter::strings::unicode_string_is_valid (data)) {
         
         // Check whether this is USFM data.
         bool id = data.find ("\\id ") != string::npos;
@@ -80,17 +80,18 @@ void bible_import_run (string location, string bible, int book, int chapter)
 // Import the USFM in $data into $bible.
 void bible_import_usfm (string data, string bible, int book, int chapter)
 {
-  if (book && chapter) {}
+  (void) book;
+  (void) chapter;
   string stylesheet = styles_logic_standard_sheet ();
-  vector <BookChapterData> book_chapter_text = usfm_import (data, stylesheet);
+  vector <filter::usfm::BookChapterData> book_chapter_text = filter::usfm::usfm_import (data, stylesheet);
   for (auto & data2 : book_chapter_text) {
-    int book_number = data2.book;
-    int chapter_number = data2.chapter;
-    string chapter_data = data2.data;
+    int book_number = data2.m_book;
+    int chapter_number = data2.m_chapter;
+    string chapter_data = data2.m_data;
     if (book_number > 0) {
-      bible_logic_store_chapter (bible, book_number, chapter_number, chapter_data);
-      string book_name = Database_Books::getUsfmFromId (book_number);
-      Database_Logs::log ("Imported " + book_name + " " + convert_to_string (chapter_number));
+      bible_logic::store_chapter (bible, book_number, chapter_number, chapter_data);
+      string book_name = database::books::get_usfm_from_id (static_cast<book_id>(book_number));
+      Database_Logs::log ("Imported " + book_name + " " + filter::strings::convert_to_string (chapter_number));
     } else {
       Database_Logs::log ("Could not import this data: " + chapter_data.substr (0, 1000));
     }
@@ -102,16 +103,16 @@ void bible_import_usfm (string data, string bible, int book, int chapter)
 void bible_import_text (string text, string bible, int book, int chapter)
 {
   // Consecutive discoveries.
-  bool discoveries_passed = true;
+  bool discoveries_passed {true};
   
   // Split the input text into separate lines.
-  vector <string> lines = filter_string_explode (text, '\n');
+  vector <string> lines = filter::strings::explode (text, '\n');
   
   // Go through the lines.
   for (size_t i = 0; i < lines.size(); i++) {
     
     // Trim the line.
-    lines[i] = filter_string_trim (lines[i]);
+    lines[i] = filter::strings::trim (lines[i]);
     
     // Skip empty line.
     if (lines[i].empty())
@@ -130,8 +131,8 @@ void bible_import_text (string text, string bible, int book, int chapter)
     // If the line is a number on its own, and the number agrees with the chapter number
     // that was set, it silently removes this line. But if it differs, an error comes up.
     if (discoveries_passed) {
-      if (number_in_string(lines[i]) == lines[i]) {
-        int number = convert_to_int (number_in_string (lines[i]));
+      if (filter::strings::number_in_string(lines[i]) == lines[i]) {
+        int number = filter::strings::convert_to_int (filter::strings::number_in_string (lines[i]));
         if (number == chapter) {
           lines[i].clear();
           continue;
@@ -147,9 +148,9 @@ void bible_import_text (string text, string bible, int book, int chapter)
     // it is considered a a normal paragraph.
     // If no punctuation at the end, it is a section heading.
     if (discoveries_passed) {
-      if (number_in_string(lines[i]).empty()) {
+      if (filter::strings::number_in_string(lines[i]).empty()) {
         string last_character = lines[i].substr(lines[i].length() -1, 1);
-        if (unicode_string_is_punctuation (last_character)) {
+        if (filter::strings::unicode_string_is_punctuation (last_character)) {
           lines[i].insert(0, "\\p ");
         } else {
           lines[i].insert(0, "\\s ");
@@ -162,11 +163,11 @@ void bible_import_text (string text, string bible, int book, int chapter)
     // The first time a number is found, a \p is prefixed.
     bool paragraph_open = false;
     if (discoveries_passed) {
-      string output;
-      string number = number_in_string(lines[i]);
+      string output {};
+      string number = filter::strings::number_in_string(lines[i]);
       // Setting for having the number only at the start of the line.
-      bool treat_as_normal_paragraph = false;
-      bool verses_at_start = true;
+      bool treat_as_normal_paragraph {false};
+      bool verses_at_start {true};
       if (verses_at_start) {
         if (lines[i].find (number) != 0) {
           number.clear();
@@ -195,8 +196,8 @@ void bible_import_text (string text, string bible, int book, int chapter)
           output.append (number);
           output.append (" ");
           lines[i].erase (0, number.length());
-          lines[i] = filter_string_trim (lines[i]);
-          number = number_in_string(lines[i]);
+          lines[i] = filter::strings::trim (lines[i]);
+          number = filter::strings::number_in_string(lines[i]);
           // Setting for discovering only first number in a paragraph.
           if (verses_at_start) {
             number.clear();
@@ -212,23 +213,23 @@ void bible_import_text (string text, string bible, int book, int chapter)
   }
   
   // Make one block of text.
-  string newtext;
+  string newtext {};
   for (unsigned int i = 0; i < lines.size(); i++) {
     if (lines[i].empty())
       continue;
-    lines[i] = filter_string_collapse_whitespace (lines[i]);
-    lines[i] = filter_string_str_replace (" \n", "\n", lines[i]);
+    lines[i] = filter::strings::collapse_whitespace (lines[i]);
+    lines[i] = filter::strings::replace (" \n", "\n", lines[i]);
     newtext.append(lines[i]);
     newtext.append("\n");
   }
   
   // If no chapter marker is found, insert it at the top.
   if (newtext.find("\\c") == string::npos) {
-    newtext.insert(0, "\\c " + convert_to_string(chapter) + "\n");
+    newtext.insert(0, "\\c " + filter::strings::convert_to_string(chapter) + "\n");
   }
 
   // Import the text as USFM.
-  bible_logic_store_chapter (bible, book, chapter, newtext);
-  string book_name = Database_Books::getUsfmFromId (book);
-  Database_Logs::log ("Imported " + book_name + " " + convert_to_string (chapter) + ": " + text);
+  bible_logic::store_chapter (bible, book, chapter, newtext);
+  string book_name = database::books::get_usfm_from_id (static_cast<book_id>(book));
+  Database_Logs::log ("Imported " + book_name + " " + filter::strings::convert_to_string (chapter) + ": " + text);
 }
