@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@
 #include <tasks/logic.h>
 #include <system/index.h>
 #include <rss/logic.h>
+#include <access/logic.h>
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Weffc++"
 #pragma GCC diagnostic ignored "-Wsuggest-override"
@@ -92,17 +93,23 @@ string bible_settings (void * webserver_request)
   string bible = request->query["bible"];
   if (bible.empty()) bible = request->post ["val1"];
   bible = access_bible::clamp (request, bible);
-  view.set_variable ("bible", escape_special_xml_characters (bible));
+  view.set_variable ("bible", filter::strings::escape_special_xml_characters (bible));
 
   
   // Whether the user has write access to this Bible.
   bool write_access = access_bible::write (request, bible);
   if (write_access) view.enable_zone ("write_access");
+  
+  
+  // Whether the user has the privilege to change the stylesheet.
+  string current_user = request->session_logic()->currentUser ();
+  bool privilege_stylesheet = access_logic::privilege_set_stylesheets (webserver_request, current_user);
+  if (privilege_stylesheet) view.enable_zone ("privilege_stylesheet");
 
   
   // The state of the checkbox.
   string checkbox = request->post ["checkbox"];
-  bool checked = convert_to_bool (request->post ["checked"]);
+  bool checked = filter::strings::convert_to_bool (request->post ["checked"]);
 
   
   // Versification.
@@ -136,7 +143,7 @@ string bible_settings (void * webserver_request)
       return page;
     } else {
       vector <string> feedback;
-      if (write_access) book_create (bible, static_cast<book_id>(convert_to_int (createbook)), -1, feedback);
+      if (write_access) book_create (bible, static_cast<book_id>(filter::strings::convert_to_int (createbook)), -1, feedback);
     }
     // User creates a book in this Bible: Set it as the default Bible.
     request->database_config_user()->setBible (bible);
@@ -148,7 +155,7 @@ string bible_settings (void * webserver_request)
   if (!deletebook.empty()) {
     string confirm = request->query["confirm"];
     if (confirm == "yes") {
-      if (write_access) bible_logic::delete_book (bible, convert_to_int (deletebook));
+      if (write_access) bible_logic::delete_book (bible, filter::strings::convert_to_int (deletebook));
     } else if (confirm == "cancel") {
     } else {
       Dialog_Yes dialog_yes = Dialog_Yes ("settings", translate("Would you like to delete this book?"));
@@ -204,7 +211,7 @@ string bible_settings (void * webserver_request)
     if (manager_level) {
       a_or_span_node = book_document.append_child("a");
       string href = filter_url_build_http_query ("book", "bible", bible);
-      href = filter_url_build_http_query (href, "book", convert_to_string (book));
+      href = filter_url_build_http_query (href, "book", filter::strings::convert_to_string (book));
       a_or_span_node.append_attribute("href") = href.c_str();
     } else {
       a_or_span_node = book_document.append_child("span");
@@ -216,14 +223,14 @@ string bible_settings (void * webserver_request)
   stringstream bookblock2 {};
   book_document.print (bookblock2, "", format_raw);
   view.set_variable ("bookblock", bookblock2.str());
-  view.set_variable ("book_count", convert_to_string (static_cast<int>(book_ids.size())));
+  view.set_variable ("book_count", filter::strings::convert_to_string (static_cast<int>(book_ids.size())));
 
 
   // Public feedback.
   if (checkbox == "public") {
     if (write_access) Database_Config_Bible::setPublicFeedbackEnabled (bible, checked);
   }
-  view.set_variable ("public", get_checkbox_status (Database_Config_Bible::getPublicFeedbackEnabled (bible)));
+  view.set_variable ("public", filter::strings::get_checkbox_status (Database_Config_Bible::getPublicFeedbackEnabled (bible)));
 
   
  
@@ -235,7 +242,7 @@ string bible_settings (void * webserver_request)
       rss_logic_feed_on_off ();
     }
   }
-  view.set_variable ("rss", get_checkbox_status (Database_Config_Bible::getSendChangesToRSS (bible)));
+  view.set_variable ("rss", filter::strings::get_checkbox_status (Database_Config_Bible::getSendChangesToRSS (bible)));
 #endif
 
   
@@ -293,7 +300,7 @@ string bible_settings (void * webserver_request)
       }
     }
   }
-  view.set_variable ("checks", get_checkbox_status (Database_Config_Bible::getDailyChecksEnabled (bible)));
+  view.set_variable ("checks", filter::strings::get_checkbox_status (Database_Config_Bible::getDailyChecksEnabled (bible)));
 #endif
 
   
