@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_CHANGES_STATISTICS_H
-#define INCLUDED_CHANGES_STATISTICS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string changes_statistics_url ();
+std::string changes_statistics_url ();
 bool changes_statistics_acl (void * webserver_request);
-string changes_statistics (void * webserver_request);
-
-
-#endif
+std::string changes_statistics (void * webserver_request);
