@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -22,29 +22,30 @@
 #include <filter/usfm.h>
 #include <database/check.h>
 #include <locale/translate.h>
+using namespace std;
 
 
 namespace checks::space {
 
 
-void double_space_usfm (string bible, int book, int chapter, int verse, string data)
+void double_space_usfm (const string & bible, int book, int chapter, int verse, const string & data)
 {
-  size_t pos = data.find ("  ");
+  const size_t pos = data.find ("  ");
   if (pos != string::npos) {
     int start = static_cast<int>(pos) - 10;
     if (start < 0) start = 0;
     string fragment = data.substr (static_cast <size_t> (start), 20);
-    Database_Check database_check;
+    Database_Check database_check {};
     database_check.recordOutput (bible, book, chapter, verse, translate ("Double space:") + " ... " + fragment + " ...");
   }
 }
 
 
-void space_before_punctuation (string bible, int book, int chapter, map <int, string> texts)
+void space_before_punctuation (const string & bible, int book, int chapter, const map <int, string> & texts)
 {
-  Database_Check database_check;
-  for (auto element : texts) {
-    int verse = element.first;
+  Database_Check database_check {};
+  for (const auto & element : texts) {
+    const int verse = element.first;
     string text = element.second;
     if (text.find (" ,") != string::npos) {
       database_check.recordOutput (bible, book, chapter, verse, translate ("Space before a comma"));
@@ -68,22 +69,22 @@ void space_before_punctuation (string bible, int book, int chapter, map <int, st
 }
 
 
-void space_end_verse (string bible, int book, int chapter, string usfm)
+void space_end_verse (const string & bible, int book, int chapter, const string & usfm)
 {
-  Database_Check database_check;
-  vector <int> verses = usfm_get_verse_numbers (usfm);
+  Database_Check database_check {};
+  vector <int> verses = filter::usfm::get_verse_numbers (usfm);
   for (auto verse : verses) {
     if (!verse) continue;
-    string text = usfm_get_verse_text (usfm, verse);
-    vector <string> items = usfm_get_markers_and_text (text);
-    for (auto item : items) {
-      if (usfm_is_usfm_marker (item)) {
-        text = filter_string_str_replace (item, "", text);
+    string text = filter::usfm::get_verse_text (usfm, verse);
+    vector <string> items = filter::usfm::get_markers_and_text (text);
+    for (const auto & item : items) {
+      if (filter::usfm::is_usfm_marker (item)) {
+        text = filter::strings::replace (item, "", text);
       }
     }
-    bool hit = false;
+    bool hit {false};
     if (!text.empty ()) {
-      string trimmed = filter_string_trim (text);
+      string trimmed = filter::strings::trim (text);
       if (trimmed.empty ()) hit = true;
       char lastchar = text.back ();
       if (lastchar == ' ') hit = true;
@@ -99,17 +100,17 @@ bool transpose_note_space (string & usfm)
   // \v 1 Verse\f + \fr 3.1\fk  keyword\ft  Text.\f* one.
   // \v 2 Verse\x + \xo 3.2\xt  Text.\x* two.
 
-  bool transposed = false;
-  size_t pos = usfm.find("  ");
+  bool transposed {false};
+  const size_t pos = usfm.find("  ");
   if (pos != string::npos) {
     map <string, string> data = {
       pair (R"(\fk  )", R"( \fk )"),
       pair (R"(\ft  )", R"( \ft )"),
       pair (R"(\xt  )", R"( \xt )")
     };
-    for (auto search_replace : data) {
-      int count = 0;
-      usfm = filter_string_str_replace (search_replace.first, search_replace.second, usfm, &count);
+    for (const auto & search_replace : data) {
+      int count {0};
+      usfm = filter::strings::replace (search_replace.first, search_replace.second, usfm, &count);
       if (count) transposed = true;
     }
   }
@@ -117,9 +118,9 @@ bool transpose_note_space (string & usfm)
 }
 
 
-void space_before_final_note_markup (string bible, int book, int chapter, int verse, string data)
+void space_before_final_note_markup (const string & bible, int book, int chapter, int verse, const string & data)
 {
-  Database_Check database_check;
+  Database_Check database_check {};
   if (data.find (R"( \f*)") != string::npos) {
     database_check.recordOutput (bible, book, chapter, verse, translate ("Space before final note markup"));
   }
