@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,21 +17,17 @@
  */
 
 
-#ifndef INCLUDED_CHECK_SPACE_H
-#define INCLUDED_CHECK_SPACE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+namespace checks::space {
 
-class Checks_Space
-{
-public:
-  static void doubleSpaceUsfm (string bible, int book, int chapter, int verse, string data);
-  static void spaceBeforePunctuation (string bible, int book, int chapter, map <int, string> texts);
-  static void spaceEndVerse (string bible, int book, int chapter, string usfm);
-private:
-};
+void double_space_usfm (const std::string & bible, int book, int chapter, int verse, const std::string & data);
+void space_before_punctuation (const std::string & bible, int book, int chapter, const std::map <int, std::string> & texts);
+void space_end_verse (const std::string & bible, int book, int chapter, const std::string & usfm);
+bool transpose_note_space (std::string & usfm);
+void space_before_final_note_markup (const std::string & bible, int book, int chapter, int verse, const std::string & data);
 
+}
 
-#endif
