@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -27,14 +27,15 @@
 #include <database/bibleimages.h>
 #include <styles/logic.h>
 #include <locale/translate.h>
+using namespace std;
 
 
-Checks_Usfm::Checks_Usfm (string bible)
+Checks_Usfm::Checks_Usfm (const string & bible)
 {
-  Database_Styles database_styles;
+  Database_Styles database_styles {};
   string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
   markers_stylesheet = database_styles.getMarkers (stylesheet);
-  for (auto marker : markers_stylesheet) {
+  for (const auto & marker : markers_stylesheet) {
     Database_Styles_Item style = database_styles.getMarkerData (stylesheet, marker);
     style_items [marker] = style;
     int styleType = style.type;
@@ -42,8 +43,8 @@ Checks_Usfm::Checks_Usfm (string bible)
 
     // Find out which markers require an endmarker.
     // And which markers are embeddable.
-    bool required_endmarker = false;
-    bool embeddable_marker = false;
+    bool required_endmarker {false};
+    bool embeddable_marker {false};
     if (styleType == StyleTypeIdentifier) {
       if (styleSubtype == IdentifierSubtypePublishedVerseMarker) {
         required_endmarker = true;
@@ -101,12 +102,12 @@ void Checks_Usfm::finalize ()
 {
   // Check on unclosed markers.
   if (open_matching_markers.size () > 0) {
-    add_result (translate ("Unclosed markers:") + " " + filter_string_implode (open_matching_markers, " "), display_nothing);
+    add_result (translate ("Unclosed markers:") + " " + filter::strings::implode (open_matching_markers, " "), display_nothing);
   }
 }
 
 
-void Checks_Usfm::check (string usfm)
+void Checks_Usfm::check (const string & usfm)
 {
   new_line_in_usfm (usfm);
   
@@ -114,15 +115,15 @@ void Checks_Usfm::check (string usfm)
 
   toc (usfm);
   
-  usfm_markers_and_text = usfm_get_markers_and_text (usfm);
+  usfm_markers_and_text = filter::usfm::get_markers_and_text (usfm);
   for (usfm_markers_and_text_pointer = 0; usfm_markers_and_text_pointer < usfm_markers_and_text.size(); usfm_markers_and_text_pointer++) {
     usfm_item = usfm_markers_and_text [usfm_markers_and_text_pointer];
-    if (usfm_is_usfm_marker (usfm_item)) {
+    if (filter::usfm::is_usfm_marker (usfm_item)) {
       
       // Get the current verse number.
       if (usfm_item == R"(\v )") {
-        string verseCode = usfm_peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
-        verse_number = convert_to_int (usfm_peek_verse_number (verseCode));
+        string verseCode = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
+        verse_number = filter::strings::convert_to_int (filter::usfm::peek_verse_number (verseCode));
       }
       
       malformed_verse_number ();
@@ -152,9 +153,9 @@ void Checks_Usfm::check (string usfm)
 void Checks_Usfm::malformed_verse_number ()
 {
   if (usfm_item == "\\v ") {
-    string code = usfm_peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
-    string cleanVerseNumber = usfm_peek_verse_number (code);
-    vector <string> v_dirtyVerseNumber = filter_string_explode (code, ' ');
+    string code = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
+    string cleanVerseNumber = filter::usfm::peek_verse_number (code);
+    vector <string> v_dirtyVerseNumber = filter::strings::explode (code, ' ');
     string dirtyVerseNumber;
     if (!v_dirtyVerseNumber.empty ()) dirtyVerseNumber = v_dirtyVerseNumber [0];
     if (cleanVerseNumber != dirtyVerseNumber) {
@@ -164,9 +165,9 @@ void Checks_Usfm::malformed_verse_number ()
 }
 
 
-void Checks_Usfm::new_line_in_usfm (string usfm)
+void Checks_Usfm::new_line_in_usfm (const string & usfm)
 {
-  size_t position = string::npos;
+  size_t position {string::npos};
   size_t pos = usfm.find ("\\\n");
   if (pos != string::npos) {
     position = pos;
@@ -178,7 +179,7 @@ void Checks_Usfm::new_line_in_usfm (string usfm)
   if (position != string::npos) {
     if (position == 0) position = 1;
     string bit = usfm.substr (position - 1, 10);
-    bit = filter_string_str_replace ("\n", " ", bit);
+    bit = filter::strings::replace ("\n", " ", bit);
     add_result (translate ("New line within USFM:") + " " + bit, display_nothing);
   }
 }
@@ -187,14 +188,14 @@ void Checks_Usfm::new_line_in_usfm (string usfm)
 void Checks_Usfm::marker_in_stylesheet ()
 {
   string marker = usfm_item.substr (1);
-  marker = filter_string_trim (marker);
-  if (!usfm_is_opening_marker (marker)) {
+  marker = filter::strings::trim (marker);
+  if (!filter::usfm::is_opening_marker (marker)) {
     if (!marker.empty ()) marker = marker.substr (0, marker.length () - 1);
   }
-  if (usfm_is_embedded_marker (marker)) {
+  if (filter::usfm::is_embedded_marker (marker)) {
     if (!marker.empty ()) marker = marker.substr (1);
   }
-  if (marker == "") return;
+  if (marker.empty()) return;
   if (in_array (marker, markers_stylesheet)) return;
   add_result (translate ("Marker not in stylesheet"), Checks_Usfm::display_current);
 }
@@ -204,18 +205,18 @@ void Checks_Usfm::malformed_id ()
 {
   string item = usfm_item.substr (0, 3);
   string ide = usfm_item.substr (0, 4);
-  if (ide == "\\ide") return;
-  if (item == "\\id") {
-    string code = usfm_peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
-    string sid =  code.substr (0, 3);
-    vector <string> vid = filter_string_explode (code, ' ');
-    string id;
+  if (ide == R"(\ide)") return;
+  if (item == R"(\id)") {
+    string code = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
+    string sid = code.substr (0, 3);
+    vector <string> vid = filter::strings::explode (code, ' ');
+    string id {};
     if (!vid.empty ()) id = vid [0];
-    int book = Database_Books::getIdFromUsfm (id);
-    if (book == 0) {
+    book_id book = database::books::get_id_from_usfm (id);
+    if (book == book_id::_unknown) {
       add_result (translate ("Unknown ID"), display_full);
     } else {
-      if (unicode_string_uppercase (id) != id) {
+      if (filter::strings::unicode_string_uppercase (id) != id) {
         add_result (translate ("ID is not in uppercase"), display_full);
       }
     }
@@ -223,11 +224,11 @@ void Checks_Usfm::malformed_id ()
 }
 
 
-void Checks_Usfm::forward_slash (string usfm)
+void Checks_Usfm::forward_slash (const string & usfm)
 {
-  string code = filter_string_str_replace ("\n", " ", usfm);
+  string code = filter::strings::replace ("\n", " ", usfm);
   size_t pos = code.find ("/");
-  string bit;
+  string bit {};
   if (pos != string::npos) {
     size_t pos2 = code.find (" ", pos);
     if (pos2 != string::npos) {
@@ -250,7 +251,7 @@ void Checks_Usfm::forward_slash (string usfm)
 void Checks_Usfm::widow_back_slash ()
 {
   string marker = usfm_item;
-  marker = filter_string_trim (marker);
+  marker = filter::strings::trim (marker);
   if (marker.length() == 1) {
     add_result (translate ("Widow backslash"), display_current);
   }
@@ -262,8 +263,8 @@ void Checks_Usfm::matching_endmarker ()
   string marker = usfm_item;
   // Remove the initial backslash, e.g. '\add' becomes 'add'.
   marker = marker.substr (1);
-  marker = filter_string_trim (marker);
-  bool isOpener = usfm_is_opening_marker (marker);
+  marker = filter::strings::trim (marker);
+  bool isOpener = filter::usfm::is_opening_marker (marker);
   if (!isOpener) {
    if (!marker.empty ()) marker = marker.substr (0, marker.length () - 1);
   }
@@ -276,9 +277,9 @@ void Checks_Usfm::matching_endmarker ()
     }
   } else {
     if (in_array (marker, open_matching_markers)) {
-      open_matching_markers = filter_string_array_diff (open_matching_markers, {marker});
+      open_matching_markers = filter::strings::array_diff (open_matching_markers, {marker});
     } else {
-      add_result (translate ("Closing marker does not match opening marker") + " " + filter_string_implode (open_matching_markers, " "), display_current);
+      add_result (translate ("Closing marker does not match opening marker") + " " + filter::strings::implode (open_matching_markers, " "), display_current);
     }
   }
 }
@@ -291,9 +292,9 @@ void Checks_Usfm::embedded_marker ()
 
   // Remove the initial backslash, e.g. '\add' becomes 'add'.
   marker = marker.substr (1);
-  marker = filter_string_trim (marker);
+  marker = filter::strings::trim (marker);
 
-  bool isOpener = usfm_is_opening_marker (marker);
+  bool isOpener = filter::usfm::is_opening_marker (marker);
 
   // Clean a closing marker, e.g. '\add*' becomes '\add'.
   if (!isOpener) {
@@ -322,7 +323,7 @@ void Checks_Usfm::embedded_marker ()
     }
   } else {
     if (in_array (marker, open_embeddable_markers)) {
-      open_embeddable_markers = filter_string_array_diff (open_embeddable_markers, {marker});
+      open_embeddable_markers = filter::strings::array_diff (open_embeddable_markers, {marker});
       if (!open_embeddable_markers.empty ()) {
         checkEmbedding = true;
       }
@@ -341,36 +342,36 @@ void Checks_Usfm::toc (string usfm)
 {
   // Only check the 66 canonical books.
   // Skip any of the other books.
-  string type = Database_Books::getType (book_number);
-  if ((type == "ot") || (type == "nt")) {
+  book_type type = database::books::get_type (static_cast<book_id>(book_number));
+  if ((type == book_type::old_testament) || (type == book_type::new_testament)) {
 
     // Check on the presence of the table of contents markers in this chapter.
-    bool toc1_present = usfm.find (usfm_get_opening_usfm (long_toc1_marker)) != string::npos;
-    bool toc2_present = usfm.find (usfm_get_opening_usfm (short_toc2_marker)) != string::npos;
-    bool toc3_present = usfm.find (usfm_get_opening_usfm (abbrev_toc3_marker)) != string::npos;
+    bool toc1_present = usfm.find (filter::usfm::get_opening_usfm (long_toc1_marker)) != string::npos;
+    bool toc2_present = usfm.find (filter::usfm::get_opening_usfm (short_toc2_marker)) != string::npos;
+    bool toc3_present = usfm.find (filter::usfm::get_opening_usfm (abbrev_toc3_marker)) != string::npos;
 
     // The markers should be on chapter 0 only.
     if (chapter_number == 0) {
       // Required: \toc1
       if (!toc1_present) {
-        add_result (translate ("The book lacks the marker for the verbose book name:") + " " + usfm_get_opening_usfm (long_toc1_marker), display_nothing);
+        add_result (translate ("The book lacks the marker for the verbose book name:") + " " + filter::usfm::get_opening_usfm (long_toc1_marker), display_nothing);
       }
       // Required: \toc2
       if (!toc2_present) {
-        add_result (translate ("The book lacks the marker for the short book name:") + " " + usfm_get_opening_usfm (short_toc2_marker), display_nothing);
+        add_result (translate ("The book lacks the marker for the short book name:") + " " + filter::usfm::get_opening_usfm (short_toc2_marker), display_nothing);
       }
     } else {
       string msg = translate ("The following marker belongs in chapter 0:") + " ";
       // Required markers.
       if (toc1_present) {
-        add_result (msg + usfm_get_opening_usfm (long_toc1_marker), display_nothing);
+        add_result (msg + filter::usfm::get_opening_usfm (long_toc1_marker), display_nothing);
       }
       if (toc2_present) {
-        add_result (msg + usfm_get_opening_usfm (short_toc2_marker), display_nothing);
+        add_result (msg + filter::usfm::get_opening_usfm (short_toc2_marker), display_nothing);
       }
       // Optional markers, but should not be anywhere else except in chapter 0.
       if (toc3_present) {
-        add_result (msg + usfm_get_opening_usfm (abbrev_toc3_marker), display_nothing);
+        add_result (msg + filter::usfm::get_opening_usfm (abbrev_toc3_marker), display_nothing);
       }
     }
   }
@@ -380,9 +381,9 @@ void Checks_Usfm::toc (string usfm)
 void Checks_Usfm::figure ()
 {
   if (usfm_item == R"(\fig )") {
-    string usfm = usfm_peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
+    string usfm = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
     string caption, alt, src, size, loc, copy, ref;
-    usfm_extract_fig (usfm, caption, alt, src, size, loc, copy, ref);
+    filter::usfm::extract_fig (usfm, caption, alt, src, size, loc, copy, ref);
     if (src.empty()) {
       add_result (translate ("Empty figure source:") + " " + usfm, display_nothing);
     } else {
@@ -409,7 +410,7 @@ vector <pair<int, string>> Checks_Usfm::get_results ()
 void Checks_Usfm::add_result (string text, int modifier)
 {
   string current = usfm_item;
-  string next = usfm_peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
+  string next = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
   next = next.substr (0, 20);
   switch (modifier) {
     case display_nothing:
@@ -423,6 +424,8 @@ void Checks_Usfm::add_result (string text, int modifier)
     case Checks_Usfm::display_full:
       text += ": " + current + next;
       break;
+    default:
+      break;
   }
   checking_results.push_back (pair (verse_number, text));
 }
@@ -438,20 +441,20 @@ void Checks_Usfm::empty_markup ()
   // bool current_is_text = false;
   // bool current_is_usfm = false;
   // bool current_is_opener = false;
-  bool current_is_closer = false;
+  bool current_is_closer {false};
   // bool current_is_embedded = false;
 
   // Flags that will describe the previous item.
   // bool previous_is_text = false;
   // bool previous_is_usfm = false;
-  bool previous_is_opener = false;
+  bool previous_is_opener {false};
   // bool previous_is_closer = false;
   // bool previous_is_embedded = false;
 
   // Set the above set of flags.
-  if (usfm_is_usfm_marker (current_item)) {
+  if (filter::usfm::is_usfm_marker (current_item)) {
     //current_is_usfm = true;
-    if (usfm_is_opening_marker(current_item)) {
+    if (filter::usfm::is_opening_marker(current_item)) {
       //current_is_opener = true;
     }
     else current_is_closer = true;
@@ -459,9 +462,9 @@ void Checks_Usfm::empty_markup ()
   } else {
     //current_is_text = true;
   }
-  if (usfm_is_usfm_marker (empty_markup_previous_item)) {
+  if (filter::usfm::is_usfm_marker (empty_markup_previous_item)) {
     //previous_is_usfm = true;
-    if (usfm_is_opening_marker(empty_markup_previous_item)) previous_is_opener = true;
+    if (filter::usfm::is_opening_marker(empty_markup_previous_item)) previous_is_opener = true;
     //else previous_is_closer = true;
     //if (usfm_is_embedded_marker(empty_markup_previous_item)) previous_is_embedded = true;
   } else {
@@ -484,14 +487,14 @@ void Checks_Usfm::empty_markup ()
 void Checks_Usfm::note ()
 {
   // Flags that describe the current item.
-  bool current_is_text = false;
+  bool current_is_text {false};
   //bool current_is_usfm = false;
-  bool current_is_opener = false;
-  bool current_is_closer = false;
+  bool current_is_opener {false};
+  bool current_is_closer {false};
   //bool current_is_embedded = false;
-  if (usfm_is_usfm_marker (usfm_item)) {
+  if (filter::usfm::is_usfm_marker (usfm_item)) {
     //current_is_usfm = true;
-    if (usfm_is_opening_marker(usfm_item)) current_is_opener = true;
+    if (filter::usfm::is_opening_marker(usfm_item)) current_is_opener = true;
     else current_is_closer = true;
     //if (usfm_is_embedded_marker(usfm_item)) current_is_embedded = true;
   } else {
@@ -503,14 +506,14 @@ void Checks_Usfm::note ()
   // From here on it is assumed that the current item is USFM, not text.
 
   // Get the plain marker, e.g. '\f ' becomes "f".
-  string current_marker = usfm_get_marker (usfm_item);
+  string current_marker = filter::usfm::get_marker (usfm_item);
   
   // Get this style's properties.
   Database_Styles_Item style = style_items [current_marker];
   
   // Set a flag if this USFM starts a footnote or an endnote or a crossreference.
   // Clear this flag if it ends the note or xref.
-  bool note_border_marker = false;
+  bool note_border_marker {false};
   if (style.type == StyleTypeFootEndNote) {
     if (style.subtype == FootEndNoteSubtypeFootnote) note_border_marker = true;
     if (style.subtype == FootEndNoteSubtypeEndnote) note_border_marker = true;
@@ -528,16 +531,15 @@ void Checks_Usfm::note ()
   if (!within_note) return;
 
   // Get the next item, that is the item following the current item.
-  string next_item = usfm_peek_text_following_marker (usfm_markers_and_text,
-                                                      usfm_markers_and_text_pointer);
+  string next_item = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
   
   // Flags that describe the next item.
-  bool next_is_text = false;
+  bool next_is_text {false};
   //bool next_is_usfm = false;
   //bool next_is_opener = false;
   //bool next_is_closer = false;
   //bool next_is_embedded = false;
-  if (usfm_is_usfm_marker (next_item)) {
+  if (filter::usfm::is_usfm_marker (next_item)) {
     //next_is_usfm = true;
     //if (usfm_is_opening_marker(next_item)) next_is_opener = true;
     //else next_is_closer = true;
@@ -548,7 +550,7 @@ void Checks_Usfm::note ()
 
   // Change, e.g. '\f ' to '\f'.
   // Remove the initial backslash, e.g. '\f' becomes 'f'.
-  string next_marker = usfm_get_marker(next_item);
+  string next_marker = filter::usfm::get_marker(next_item);
 
   // If the current item is opening markup ...
   if (!current_is_opener) return;
