@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -34,9 +34,9 @@ void checks_verses::missing_punctuation_at_end (const string & bible, int book,
                                                 const string & center_marks, const string & end_marks,
                                                 const string & disregards)
 {
-  const vector <string> centermarks = filter_string_explode (center_marks, ' ');
-  const vector <string> endmarks = filter_string_explode (end_marks, ' ');
-  const vector <string> ignores = filter_string_explode (disregards, ' ');
+  const vector <string> centermarks = filter::strings::explode (center_marks, ' ');
+  const vector <string> endmarks = filter::strings::explode (end_marks, ' ');
+  const vector <string> ignores = filter::strings::explode (disregards, ' ');
   Database_Check database_check {};
   for (const auto & element : verses) {
     int verse = element.first;
@@ -44,10 +44,10 @@ void checks_verses::missing_punctuation_at_end (const string & bible, int book,
     if (verse == 0) continue;
     if (text.empty ()) continue;
     for (const auto & ignore_text : ignores) {
-      text = filter_string_str_replace (ignore_text, string(), text);
+      text = filter::strings::replace (ignore_text, string(), text);
     }
-    const size_t text_length = unicode_string_length (text);
-    const string lastCharacter = unicode_string_substr (text, text_length - 1, 1);
+    const size_t text_length = filter::strings::unicode_string_length (text);
+    const string lastCharacter = filter::strings::unicode_string_substr (text, text_length - 1, 1);
     if (in_array (lastCharacter, centermarks)) continue;
     if (in_array (lastCharacter, endmarks)) continue;
     database_check.recordOutput (bible, book, chapter, verse, translate ("No punctuation at end of verse:") + " " + lastCharacter);
