@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_CLIENT_INDEX_H
-#define INCLUDED_CLIENT_INDEX_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string client_index_url ();
+std::string client_index_url ();
 bool client_index_acl (void * webserver_request);
-string client_index (void * webserver_request);
-
-
-#endif
+std::string client_index (void * webserver_request);
