@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 #include <database/books.h>
 #include <database/config/bible.h>
 #include <jobs/index.h>
+using namespace std;
 
 
 void compare_compare (string bible, string compare, int jobId)
@@ -90,7 +91,7 @@ void compare_compare (string bible, string compare, int jobId)
   for (auto & book : books) {
 
     
-    string bookName = Database_Books::getEnglishFromId (book);
+    string bookName = database::books::get_english_from_id (static_cast<book_id>(book));
     database_jobs.set_progress (jobId, bookName);
     
     
@@ -127,7 +128,7 @@ void compare_compare (string bible, string compare, int jobId)
       
       // Look for, report, and skip missing chapters in the source Bible.
       if (find (bibleChapters.begin(), bibleChapters.end(), chapter) == bibleChapters.end ()) {
-        absent.push_back (translate("Bible") + " '" + bible + "' " + translate ("does not contain") + " " + bookName + " " + convert_to_string (chapter) + ".");
+        absent.push_back (translate("Bible") + " '" + bible + "' " + translate ("does not contain") + " " + bookName + " " + filter::strings::convert_to_string (chapter) + ".");
         continue;
       }
 
@@ -135,7 +136,7 @@ void compare_compare (string bible, string compare, int jobId)
       // Look for, report, and skip missing chapters in the comparison USFM data.
       if (find (compareChapters.begin(), compareChapters.end(), chapter) == compareChapters.end()) {
         if (find (resourceChapters.begin(), resourceChapters.end(), chapter) == resourceChapters.end()) {
-          absent.push_back (translate("Bible/Resource") + " '" + compare + "' " + translate ("does not contain") + " " + bookName + " " + convert_to_string (chapter) + ".");
+          absent.push_back (translate("Bible/Resource") + " '" + compare + "' " + translate ("does not contain") + " " + bookName + " " + filter::strings::convert_to_string (chapter) + ".");
           continue;
         }
       }
@@ -151,8 +152,8 @@ void compare_compare (string bible, string compare, int jobId)
       
       
       // Get the combined set of verses in the chapter of the Bible and of the USFM to compare with.
-      vector <int> bible_verse_numbers = usfm_get_verse_numbers (bible_chapter_usfm);
-      vector <int> compare_verse_numbers = usfm_get_verse_numbers (compare_chapter_usfm);
+      vector <int> bible_verse_numbers = filter::usfm::get_verse_numbers (bible_chapter_usfm);
+      vector <int> compare_verse_numbers = filter::usfm::get_verse_numbers (compare_chapter_usfm);
       vector <int> verses;
       {
         set <int> verseset;
@@ -167,14 +168,14 @@ void compare_compare (string bible, string compare, int jobId)
  
 
         // Get the USFM of verse of the Bible and comparison USFM, and skip it if both are the same.
-        string bible_verse_usfm = usfm_get_verse_text (bible_chapter_usfm, verse);
-        string compare_verse_usfm = usfm_get_verse_text (compare_chapter_usfm, verse);
+        string bible_verse_usfm = filter::usfm::get_verse_text (bible_chapter_usfm, verse);
+        string compare_verse_usfm = filter::usfm::get_verse_text (compare_chapter_usfm, verse);
         if (bible_verse_usfm == compare_verse_usfm) continue;
         
         Filter_Text filter_text_bible = Filter_Text (bible);
         Filter_Text filter_text_compare = Filter_Text (compare);
-        filter_text_bible.html_text_standard = new Html_Text ("");
-        filter_text_compare.html_text_standard = new Html_Text ("");
+        filter_text_bible.html_text_standard = new HtmlText ("");
+        filter_text_compare.html_text_standard = new HtmlText ("");
         filter_text_bible.text_text = new Text_Text ();
         filter_text_compare.text_text = new Text_Text ();
         filter_text_bible.add_usfm_code (bible_verse_usfm);
@@ -187,11 +188,11 @@ void compare_compare (string bible, string compare, int jobId)
         string compare_text = filter_text_compare.text_text->get ();
         if (bible_text != compare_text) {
           string modification = filter_diff_diff (compare_text, bible_text);
-          result.push_back (filter_passage_display (book, chapter, convert_to_string (verse)) + " " + modification);
-          new_verses.push_back (filter_passage_display (book, chapter, convert_to_string (verse)) + " " + bible_text);
+          result.push_back (filter_passage_display (book, chapter, filter::strings::convert_to_string (verse)) + " " + modification);
+          new_verses.push_back (filter_passage_display (book, chapter, filter::strings::convert_to_string (verse)) + " " + bible_text);
         }
         string modification = filter_diff_diff (compare_verse_usfm, bible_verse_usfm);
-        raw.push_back (filter_passage_display (book, chapter, convert_to_string (verse)) + " " + modification);
+        raw.push_back (filter_passage_display (book, chapter, filter::strings::convert_to_string (verse)) + " " + modification);
       }
     }
   }
@@ -229,7 +230,7 @@ void compare_compare (string bible, string compare, int jobId)
       line.append ("</p>");
     }
   }
-  database_jobs.set_result (jobId, filter_string_implode (result, "\n"));
+  database_jobs.set_result (jobId, filter::strings::implode (result, "\n"));
   
   
   Database_Logs::log (translate("Comparison is ready"), Filter_Roles::consultant ());
