@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ string http_network_port ()
   string path = filter_url_create_root_path ({config::logic::config_folder (), "network-port"});
   config_globals_negotiated_port_number = filter_url_file_get_contents (path);
   // Remove white-space, e.g. a new line, that easily makes its way into the configuration file.
-  config_globals_negotiated_port_number = filter_string_trim (config_globals_negotiated_port_number);
+  config_globals_negotiated_port_number = filter::strings::trim (config_globals_negotiated_port_number);
   // Default port number.
   if (config_globals_negotiated_port_number.empty ()) config_globals_negotiated_port_number = "8080";
   // Done.
@@ -78,13 +78,13 @@ string https_network_port ()
   string path = filter_url_create_root_path ({config::logic::config_folder (), "network-port-secure"});
   string port = filter_url_file_get_contents (path);
   // Remove white-space, e.g. a new line, that easily makes its way into the configuration file.
-  port = filter_string_trim (port);
+  port = filter::strings::trim (port);
   // Default value.
   if (port.empty ()) {
     // The secure port is the plain http port plus one.
-    int iport = convert_to_int (config::logic::http_network_port ());
+    int iport = filter::strings::convert_to_int (config::logic::http_network_port ());
     iport++;
-    port = convert_to_string (iport);
+    port = filter::strings::convert_to_string (iport);
   }
   return port;
 }
@@ -102,7 +102,7 @@ bool demo_enabled ()
 string admin_username ()
 {
   string path = filter_url_create_root_path ({config::logic::config_folder (), "admin-username"});
-  return filter_string_trim (filter_url_file_get_contents (path));
+  return filter::strings::trim (filter_url_file_get_contents (path));
 }
 
 
@@ -110,7 +110,7 @@ string admin_username ()
 string admin_password ()
 {
   string path = filter_url_create_root_path ({config::logic::config_folder (), "admin-password"});
-  return filter_string_trim (filter_url_file_get_contents (path));
+  return filter::strings::trim (filter_url_file_get_contents (path));
 }
 
 
@@ -118,11 +118,11 @@ string admin_password ()
 string admin_email ()
 {
   string path = filter_url_create_root_path ({config::logic::config_folder (), "admin-email"});
-  return filter_string_trim (filter_url_file_get_contents (path));
+  return filter::strings::trim (filter_url_file_get_contents (path));
 }
 
 
-// Replacement function for missing "stoi" on platform like Android.
+// Replacement function for missing "stoi" on platforms like Android.
 int my_stoi (const string& str, void * idx, int base)
 {
 #ifdef HAVE_STOI
@@ -185,7 +185,7 @@ string manual_user_facing_url ()
   string path = filter_url_create_root_path ({config::logic::config_folder (), "userfacingurl.conf"});
   string url = filter_url_file_get_contents (path);
   // Remove white space.
-  url = filter_string_trim (url);
+  url = filter::strings::trim (url);
   // The previous file contained dummy text by default. Remove that.
   if (url.length () <= 6) url.clear ();
   // Ensure it ends with a slash.
@@ -251,7 +251,7 @@ void swipe_enabled (void * webserver_request, string & script)
 {
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
-  string true_false = "false";
+  string true_false {"false"};
   if (request->session_logic ()->touchEnabled ()) {
     if (request->database_config_user ()->getSwipeActionsAvailable ()) {
       true_false = "true";
@@ -265,62 +265,20 @@ void swipe_enabled (void * webserver_request, string & script)
 }
 
 
-// Whether the free Indonesian Cloud is enabled.
-bool indonesian_cloud_free ()
+// Whether the Indonesian Member Cloud is enabled.
+bool indonesian_member_cloud ()
 {
-  // Keep status in memory once it has been read from disk.
   // This is to speed up things.
-  static bool read = false;
-  static bool status = false;
+  static bool read {false};
+  static bool status {false};
   if (read) return status;
   
   // Read the status from disk and cache it.
-  string path = filter_url_create_root_path ({config::logic::config_folder (), "indonesiancloudfree"});
+  string path = filter_url_create_root_path ({config::logic::config_folder (), "indonesianmembercloud"});
   status = file_or_dir_exists (path);
   read = true;
-  
-  return status;
-}
 
-
-// Whether the free Indonesian Cloud Free Simple is enabled.
-// It is just like the regular demo setup with less feature:
-// 1. It only has an account with Consultant access level registered.
-// 2. It gives no access to account creation from menu
-// 3. It has different workspace defaults.
-bool indonesian_cloud_free_simple ()
-{
-  // Keep status in memory once it has been read from disk.
-  // This is to speed up things.
-  static bool read = false;
-  static bool status = false;
-  if (read) return status;
-  
-  // Read the status from disk and cache it.
-  string path = filter_url_create_root_path ({config::logic::config_folder (), "indonesiancloudfreesimple"});
-  status = file_or_dir_exists (path);
-  read = true;
-  
-  return status;
-}
-
-
-// Whether the free Indonesian Cloud Free Individual is enabled.
-// It is just like the default Indonesian Cloud Free,
-// but with no access to the consultation notes feature.
-bool indonesian_cloud_free_individual ()
-{
-  // Keep status in memory once it has been read from disk.
-  // This is to speed up things.
-  static bool read = false;
-  static bool status = false;
-  if (read) return status;
-  
-  // Read the status from disk and cache it.
-  string path = filter_url_create_root_path ({config::logic::config_folder (), "indonesiancloudfreeindividual"});
-  status = file_or_dir_exists (path);
-  read = true;
-  
+  // Done.
   return status;
 }
 
@@ -328,19 +286,10 @@ bool indonesian_cloud_free_individual ()
 // Whether the default Bibledit configuration is enabled.
 bool default_bibledit_configuration ()
 {
-  // Keep status in memory once it has been read from disk.
-  // This is to speed up things.
-  static bool read = false;
-  static bool status = true;
-  if (read) return status;
-  
-  // If any of the special configurations is enabled, the default configuration is disabled.
-  if (config::logic::indonesian_cloud_free ()) status = false;
-  if (config::logic::indonesian_cloud_free_simple ()) status = false;
-  if (config::logic::indonesian_cloud_free_individual ()) status = false;
-  read = true;
-  
-  return status;
+  // If any other configuration is active, then the default Bibledit configuration is not active.
+  if (indonesian_member_cloud ()) return false;
+  // No other configuration is active: Default Bibledit config is active.
+  return true;
 }
 
 
