@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,29 +17,25 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_CONFIRM_WORKER_H
-#define INCLUDED_CONFIRM_WORKER_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 #ifdef HAVE_CLOUD
 
-
 class Confirm_Worker
 {
 public:
   Confirm_Worker (void * webserver_request_in);
-  void setup (string to, string initial_subject, string initial_body, string query, string subsequent_subject, string subsequent_body);
-  bool handleEmail (string from, string subject, string body);
+  void setup (std::string mailto, std::string username,
+              std::string initial_subject, std::string initial_body,
+              std::string query,
+              std::string subsequent_subject, std::string subsequent_body);
+  bool handleEmail (std::string from, std::string subject, std::string body);
+  bool handleLink (std::string & email);
 private:
-  void * webserver_request;
-  void informManagers (string email, string body);
+  void * webserver_request {nullptr};
+  void informManagers (std::string email, std::string body);
 };
 
-
-#endif
-
-
 #endif
