@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -89,25 +89,25 @@ void Database_Config_Bible::setValue (string bible, const char * key, string val
 
 bool Database_Config_Bible::getBValue (string bible, const char * key, bool default_value)
 {
-  return convert_to_bool (getValue (bible, key, convert_to_string (default_value).c_str()));
+  return filter::strings::convert_to_bool (getValue (bible, key, filter::strings::convert_to_string (default_value).c_str()));
 }
 
 
 void Database_Config_Bible::setBValue (string bible, const char * key, bool value)
 {
-  setValue (bible, key, convert_to_string (value));
+  setValue (bible, key, filter::strings::convert_to_string (value));
 }
 
 
 int Database_Config_Bible::getIValue (string bible, const char * key, int default_value)
 {
-  return convert_to_int (getValue (bible, key, convert_to_string (default_value).c_str()));
+  return filter::strings::convert_to_int (getValue (bible, key, filter::strings::convert_to_string (default_value).c_str()));
 }
 
 
 void Database_Config_Bible::setIValue (string bible, const char * key, int value)
 {
-  setValue (bible, key, convert_to_string (value));
+  setValue (bible, key, filter::strings::convert_to_string (value));
 }
 
 
@@ -564,7 +564,7 @@ void Database_Config_Bible::setExportStylesheet (string bible, string value)
 
 string Database_Config_Bible::getVersificationSystem (string bible)
 {
-  return getValue (bible, "versification-system", english ());
+  return getValue (bible, "versification-system", filter::strings::english ());
 }
 void Database_Config_Bible::setVersificationSystem (string bible, string value)
 {
