@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/date.h>
 #include <config/globals.h>
 #include <database/sqlite.h>
+using namespace std;
 
 
 // Database resilience: 
@@ -95,7 +96,7 @@ int Database_Jobs::get_new_id ()
   // Iterate till a non-existing identifier is found.
   int id;
   do {
-    id = filter_string_rand (100'000'000, 999'999'999);
+    id = filter::strings::rand (100'000'000, 999'999'999);
   } while (id_exists (id));
   // Store the new id so it can't be given out again just now.
   // Also store the timestamp. used for entry expiry.
@@ -137,7 +138,7 @@ int Database_Jobs::get_level (int id)
   vector <string> levels = database_sqlite_query (db, sql.sql) ["level"];
   database_sqlite_disconnect (db);
   if (!levels.empty()) {
-    return convert_to_int (levels[0]);
+    return filter::strings::convert_to_int (levels[0]);
   }
   return 0;
 }
