@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,34 +17,28 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_JOBS_H
-#define INCLUDED_DATABASE_JOBS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_Jobs
 {
 public:
   void create ();
   void optimize ();
   void trim ();
-  bool idExists (int id);
-  int getNewId ();
-  void setLevel (int id, int level);
-  int getLevel (int id);
-  void setStart (int id, string start);
-  string getStart (int id);
-  void setPercentage (int id, int percentage);
-  string getPercentage (int id);
-  void setProgress (int id, string progress);
-  string getProgress (int id);
-  void setResult (int id, string result);
-  string getResult (int id);
+  bool id_exists (int id);
+  int get_new_id ();
+  void set_level (int id, int level);
+  int get_level (int id);
+  void set_start (int id, std::string start);
+  std::string get_start (int id);
+  void set_percentage (int id, int percentage);
+  std::string get_percentage (int id);
+  void set_progress (int id, std::string progress);
+  std::string get_progress (int id);
+  void set_result (int id, std::string result);
+  std::string get_result (int id);
 private:
   sqlite3 * connect ();
 };
-
-
-#endif
