@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,20 +21,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <config/libraries.h>
 
-class Database_Mail_User
+struct Database_Mail_User
 {
-public:
-  int rowid;
-  int timestamp;
-  string subject;
+  int rowid {0};
+  int timestamp {0};
+  std::string subject {};
 };
 
-class Database_Mail_Item
+struct Database_Mail_Item
 {
-public:
-  string username;
-  string subject;
-  string body;
+  std::string username {};
+  std::string subject {};
+  std::string body {};
 };
 
 class Database_Mail
@@ -42,18 +40,20 @@ class Database_Mail
 public:
   Database_Mail (void * webserver_request_in);
   ~Database_Mail ();
+  Database_Mail(const Database_Mail&) = delete;
+  Database_Mail operator=(const Database_Mail&) = delete;
   void create ();
   void optimize ();
   void trim ();
-  void send (string to, string subject, string body, int time = 0);
+  void send (std::string to, std::string subject, std::string body, int time = 0);
   int getMailCount ();
-  vector <Database_Mail_User> getMails ();
+  std::vector <Database_Mail_User> getMails ();
   void erase (int id);
   Database_Mail_Item get (int id);
-  vector <int> getMailsToSend ();
+  std::vector <int> getMailsToSend ();
   void postpone (int id);
-  vector <int> getAllMails ();
+  std::vector <int> getAllMails ();
 private:
   sqlite3 * connect ();
-  void * webserver_request;
+  void * webserver_request {nullptr};
 };
