@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,23 +17,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_SAMPLE_H
-#define INCLUDED_DATABASE_SAMPLE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_Sample
 {
 public:
   static void create ();
-  static void store (string file, string data);
-  static vector <int> get ();
-  static void get (int rowid, string & file, string & data);
+  static void store (std::string file, std::string data);
+  static std::vector <int> get ();
+  static void get (int rowid, std::string & file, std::string & data);
 private:
   static const char * name ();
 };
-
-
-#endif
