@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,21 +17,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_VOLATILE_H
-#define INCLUDED_DATABASE_VOLATILE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_Volatile
 {
 public:
-  static string getValue (int id, const string& key);
-  static void setValue (int id, const string& key, const string& value);
+  static std::string getValue (int id, const std::string& key);
+  static void setValue (int id, const std::string& key, const std::string& value);
 private:
-  static string filename (int id, string key);
+  static std::string filename (int id, std::string key);
 };
-
-
-#endif
