@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,24 +17,20 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DIALOG_ENTRY_H
-#define INCLUDED_DIALOG_ENTRY_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Dialog_Entry
 {
 public:
-  Dialog_Entry (string url, string question, string value, string submit, string help);
+  Dialog_Entry (std::string url, std::string question, std::string value, std::string submit, std::string help);
   ~Dialog_Entry ();
-  void add_query (string parameter, string value);
-  string run ();
+  Dialog_Entry(const Dialog_Entry&) = delete;
+  Dialog_Entry operator=(const Dialog_Entry&) = delete;
+  void add_query (std::string parameter, std::string value);
+  std::string run ();
 private:
-  void * assets_view = NULL;
-  string base_url;
+  void * assets_view {nullptr};
+  std::string base_url {};
 };
-
-
-#endif
