@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -24,12 +24,14 @@
 class Dialog_Upload
 {
 public:
-  Dialog_Upload (string url, string question);
+  Dialog_Upload (std::string url, std::string question);
   ~Dialog_Upload ();
-  void add_upload_query (string parameter, string value);
-  string run ();
+  Dialog_Upload(const Dialog_Upload&) = delete;
+  Dialog_Upload operator=(const Dialog_Upload&) = delete;
+  void add_upload_query (std::string parameter, std::string value);
+  std::string run ();
 private:
-  void * assets_view = NULL;
-  string base_url;
-  map <string, string> upload_query;
+  void * assets_view = {nullptr};
+  std::string base_url {};
+  std::map <std::string, std::string> upload_query {};
 };
