@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 // Dialog that asks the user for confirmation to perform an action.
 // $url: The url of the page where to go to on clicking Cancel or Yes.
 // $question: The question to ask.
-Dialog_Yes::Dialog_Yes (string url, string question)
+Dialog_Yes::Dialog_Yes (std::string url, std::string question)
 {
   Assets_View * view = new Assets_View ();
   base_url = url;
@@ -43,21 +43,21 @@ Dialog_Yes::~Dialog_Yes ()
 
 
 // Adds a query to the URL for going to the page on clicking Cancel or Yes.
-void Dialog_Yes::add_query (string parameter, string value)
+void Dialog_Yes::add_query (std::string parameter, std::string value)
 {
   base_url = filter_url_build_http_query (base_url, parameter, value);
 }
 
 
-string Dialog_Yes::run ()
+std::string Dialog_Yes::run ()
 {
   Assets_View * view = static_cast<Assets_View *>(assets_view);
-  string yes = filter_url_build_http_query (base_url, "confirm", "yes");
-  string cancel = filter_url_build_http_query (base_url, "confirm", "cancel");
+  std::string yes = filter_url_build_http_query (base_url, "confirm", "yes");
+  std::string cancel = filter_url_build_http_query (base_url, "confirm", "cancel");
   view->set_variable ("yes", yes);
   view->set_variable ("cancel", cancel);
-  string page = view->render ("dialog", "yes");
-  page += Assets_Page::footer ();
+  std::string page = view->render ("dialog", "yes");
+  page += assets_page::footer ();
   return page;
 }
 
