@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -67,8 +67,8 @@ string edit_save (void * webserver_request)
   }
 
   string bible = request->post["bible"];
-  int book = convert_to_int (request->post["book"]);
-  int chapter = convert_to_int (request->post["chapter"]);
+  int book = filter::strings::convert_to_int (request->post["book"]);
+  int chapter = filter::strings::convert_to_int (request->post["chapter"]);
   string html = request->post["html"];
   string checksum = request->post["checksum"];
   string unique_id = request->post ["id"];
@@ -79,14 +79,14 @@ string edit_save (void * webserver_request)
   }
 
   html = filter_url_tag_to_plus (html);
-  html = filter_string_trim (html);
+  html = filter::strings::trim (html);
 
   if (html.empty ()) {
     Database_Logs::log (translate ("There was no text.") + " " + translate ("Nothing was saved.") + " " + translate ("The original text of the chapter was reloaded."));
     return translate("Nothing to save");
   }
 
-  if (!unicode_string_is_valid (html)) {
+  if (!filter::strings::unicode_string_is_valid (html)) {
     Database_Logs::log ("The text was not valid Unicode UTF-8. The chapter could not saved and has been reverted to the last good version.");
     return translate("Save failure");
   }
@@ -116,7 +116,7 @@ string edit_save (void * webserver_request)
   user_usfm = book_chapter_text[0].m_data;
   bool chapter_ok = (((book_number == book) || (book_number == 0)) && (chapter_number == chapter));
   if (!chapter_ok) {
-    return translate("Incorrect chapter") + " " + convert_to_string (chapter_number);
+    return translate("Incorrect chapter") + " " + filter::strings::convert_to_string (chapter_number);
   }
   
   // Collect some data about the changes for this user
@@ -190,14 +190,14 @@ string edit_save (void * webserver_request)
   // Convert to XML for comparison.
   // Remove spaces before comparing.
   // Goal: Entering a space in the editor does not cause a reload.
-  html = html2xml (html);
-  html = filter_string_str_replace (" ", "", html);
-  html = filter_string_str_replace (unicode_non_breaking_space_entity (), "", html);
-  filter_string_replace_between (html, "<", ">", "");
-  converted_html = html2xml (converted_html);
-  converted_html = filter_string_str_replace (" ", "", converted_html);
-  converted_html = filter_string_str_replace (unicode_non_breaking_space_entity (), "", converted_html);
-  filter_string_replace_between (converted_html, "<", ">", "");
+  html = filter::strings::html2xml (html);
+  html = filter::strings::replace (" ", "", html);
+  html = filter::strings::replace (filter::strings::unicode_non_breaking_space_entity (), "", html);
+  filter::strings::replace_between (html, "<", ">", "");
+  converted_html = filter::strings::html2xml (converted_html);
+  converted_html = filter::strings::replace (" ", "", converted_html);
+  converted_html = filter::strings::replace (filter::strings::unicode_non_breaking_space_entity (), "", converted_html);
+  filter::strings::replace_between (converted_html, "<", ">", "");
   // If round trip conversion differs, send a known string to the browser,
   // to signal the browser to reload the reformatted chapter.
   if (html != converted_html) return locale_logic_text_reformat ();
