@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@
 #include <developer/logic.h>
 #include <rss/logic.h>
 #include <sendreceive/logic.h>
+using namespace std;
 
 
 string edit_update_url ()
@@ -53,7 +54,7 @@ string edit_update_url ()
 bool edit_update_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
@@ -97,8 +98,8 @@ string edit_update (void * webserver_request)
   string unique_id;
   if (good2go) {
     bible = request->post["bible"];
-    book = convert_to_int (request->post["book"]);
-    chapter = convert_to_int (request->post["chapter"]);
+    book = filter::strings::convert_to_int (request->post["book"]);
+    chapter = filter::strings::convert_to_int (request->post["chapter"]);
     loaded_html = request->post["loaded"];
     edited_html = request->post["edited"];
     checksum1 = request->post["checksum1"];
@@ -109,14 +110,14 @@ string edit_update (void * webserver_request)
 
   // Checksums of the loaded and edited html.
   if (good2go) {
-    if (Checksum_Logic::get (loaded_html) != checksum1) {
+    if (checksum_logic::get (loaded_html) != checksum1) {
       request->response_code = 409;
       messages.push_back (translate ("Checksum error"));
       good2go = false;
     }
   }
   if (good2go) {
-    if (Checksum_Logic::get (edited_html) != checksum2) {
+    if (checksum_logic::get (edited_html) != checksum2) {
       request->response_code = 409;
       messages.push_back (translate ("Checksum error"));
       good2go = false;
@@ -127,13 +128,13 @@ string edit_update (void * webserver_request)
   // Decode html encoded in javascript, and clean it.
   loaded_html = filter_url_tag_to_plus (loaded_html);
   edited_html = filter_url_tag_to_plus (edited_html);
-  loaded_html = filter_string_trim (loaded_html);
-  edited_html = filter_string_trim (edited_html);
+  loaded_html = filter::strings::trim (loaded_html);
+  edited_html = filter::strings::trim (edited_html);
 
   
   // Check on valid UTF-8.
   if (good2go) {
-    if (!unicode_string_is_valid (loaded_html) || !unicode_string_is_valid (edited_html)) {
+    if (!filter::strings::unicode_string_is_valid (loaded_html) || !filter::strings::unicode_string_is_valid (edited_html)) {
       messages.push_back (translate ("Cannot update: Needs Unicode"));
       good2go = false;
     }
@@ -142,7 +143,7 @@ string edit_update (void * webserver_request)
 
   bool bible_write_access = false;
   if (good2go) {
-    bible_write_access = AccessBible::BookWrite (request, string(), bible, book);
+    bible_write_access = access_bible::book_write (request, string(), bible, book);
   }
 
 
@@ -187,23 +188,23 @@ string edit_update (void * webserver_request)
     editor_export.run ();
     edited_chapter_usfm = editor_export.get ();
   }
-  string existing_chapter_usfm = filter_string_trim (old_chapter_usfm);
+  string existing_chapter_usfm = filter::strings::trim (old_chapter_usfm);
 
 
   // Check that the edited USFM contains no more than, and exactly the same as,
   // the book and chapter that was loaded in the editor.
   if (good2go && bible_write_access) {
-    vector <BookChapterData> book_chapter_text = usfm_import (edited_chapter_usfm, stylesheet);
+    vector <filter::usfm::BookChapterData> book_chapter_text = filter::usfm::usfm_import (edited_chapter_usfm, stylesheet);
     if (book_chapter_text.size () != 1) {
       Database_Logs::log (translate ("A user tried to save something different from exactly one chapter"));
       messages.push_back (translate("Incorrect chapter"));
     }
-    int book_number = book_chapter_text[0].book;
-    int chapter_number = book_chapter_text[0].chapter;
-    edited_chapter_usfm = book_chapter_text[0].data;
+    int book_number = book_chapter_text[0].m_book;
+    int chapter_number = book_chapter_text[0].m_chapter;
+    edited_chapter_usfm = book_chapter_text[0].m_data;
     bool chapter_ok = (((book_number == book) || (book_number == 0)) && (chapter_number == chapter));
     if (!chapter_ok) {
-      messages.push_back (translate("Incorrect chapter") + " " + convert_to_string (chapter_number));
+      messages.push_back (translate("Incorrect chapter") + " " + filter::strings::convert_to_string (chapter_number));
     }
   }
 
@@ -226,9 +227,9 @@ string edit_update (void * webserver_request)
       // Do a merge while giving priority to the USFM already in the chapter.
       string merged_chapter_usfm = filter_merge_run (loaded_chapter_usfm, edited_chapter_usfm, existing_chapter_usfm, true, conflicts);
       // Mail the user if there is a merge anomaly.
-      bible_logic_optional_merge_irregularity_email (bible, book, chapter, username, loaded_chapter_usfm, edited_chapter_usfm, merged_chapter_usfm);
+      bible_logic::optional_merge_irregularity_email (bible, book, chapter, username, loaded_chapter_usfm, edited_chapter_usfm, merged_chapter_usfm);
       filter_merge_add_book_chapter (conflicts, book, chapter);
-      bible_logic_merge_irregularity_mail ({username}, conflicts);
+      bible_logic::merge_irregularity_mail ({username}, conflicts);
       // Let the merged data now become the edited data (so it gets saved properly).
       edited_chapter_usfm = merged_chapter_usfm;
     }
@@ -249,7 +250,7 @@ string edit_update (void * webserver_request)
   // It might cause confusion more than it clarifies.
   //if (good2go && bible_write_access && text_was_edited) {
     //if (loaded_chapter_usfm != existing_chapter_usfm) {
-      //bible_logic_recent_save_email (bible, book, chapter, username, loaded_chapter_usfm, existing_chapter_usfm);
+      //bible_logic::recent_save_email (bible, book, chapter, username, loaded_chapter_usfm, existing_chapter_usfm);
     //}
   //}
 
@@ -259,15 +260,15 @@ string edit_update (void * webserver_request)
   // If there's double spaces removed here,
   // then later in this code, the editor will load that text.
   if (good2go && bible_write_access && text_was_edited) {
-    edited_chapter_usfm = filter_string_collapse_whitespace(edited_chapter_usfm);
+    edited_chapter_usfm = filter::strings::collapse_whitespace(edited_chapter_usfm);
   }
   
   // Safely store the chapter.
   string explanation;
   string message;
   if (good2go && bible_write_access && text_was_edited) {
-    message = usfm_safely_store_chapter (request, bible, book, chapter, edited_chapter_usfm, explanation);
-    bible_logic_unsafe_save_mail (message, explanation, username, edited_chapter_usfm, book, chapter);
+    message = filter::usfm::safely_store_chapter (request, bible, book, chapter, edited_chapter_usfm, explanation);
+    bible_logic::unsafe_save_mail (message, explanation, username, edited_chapter_usfm, book, chapter);
     if (!message.empty ()) messages.push_back (message);
   }
 
@@ -311,12 +312,12 @@ string edit_update (void * webserver_request)
   // The response starts with the save message(s) if any.
   // The message(s) contain information about save success or failure.
   // Send it to the browser for display to the user.
-  response.append (filter_string_implode (messages, " | "));
+  response.append (filter::strings::implode (messages, " | "));
 
   
   // Add separator and the new chapter identifier to the response.
   response.append (separator);
-  response.append (convert_to_string (newID));
+  response.append (filter::strings::convert_to_string (newID));
 
   
   // The main purpose of the following block of code is this:
@@ -341,39 +342,39 @@ string edit_update (void * webserver_request)
     vector <int> sizes;
     vector <string> operators;
     vector <string> content;
-    bible_logic_html_to_editor_updates (editor_html, server_html, positions, sizes, operators, content);
+    bible_logic::html_to_editor_updates (editor_html, server_html, positions, sizes, operators, content);
     // Encode the condensed differences for the response to the Javascript editor.
     for (size_t i = 0; i < positions.size(); i++) {
       response.append ("#_be_#");
-      response.append (convert_to_string (positions[i]));
+      response.append (filter::strings::convert_to_string (positions[i]));
       response.append ("#_be_#");
       string operation = operators[i];
       response.append (operation);
-      if (operation == bible_logic_insert_operator ()) {
+      if (operation == bible_logic::insert_operator ()) {
         string text = content[i];
-        string character = unicode_string_substr (text, 0, 1);
+        string character = filter::strings::unicode_string_substr (text, 0, 1);
         response.append ("#_be_#");
         response.append (character);
-        size_t length = unicode_string_length (text);
-        string format = unicode_string_substr (text, 1, length - 1);
+        size_t length = filter::strings::unicode_string_length (text);
+        string format = filter::strings::unicode_string_substr (text, 1, length - 1);
         response.append ("#_be_#");
         response.append (format);
         // Also add the size of the character in UTF-16 format, 2-bytes or 4 bytes, as size 1 or 2.
         response.append ("#_be_#");
-        response.append (convert_to_string (sizes[i]));
+        response.append (filter::strings::convert_to_string (sizes[i]));
       }
-      else if (operation == bible_logic_delete_operator ()) {
+      else if (operation == bible_logic::delete_operator ()) {
         // When deleting a UTF-16 character encoded in 4 bytes,
         // then the size in Quilljs is 2 instead of 1.
         // So always give the size when deleting a character.
         response.append ("#_be_#");
-        response.append (convert_to_string (sizes[i]));
+        response.append (filter::strings::convert_to_string (sizes[i]));
       }
-      else if (operation == bible_logic_format_paragraph_operator ()) {
+      else if (operation == bible_logic::format_paragraph_operator ()) {
         response.append ("#_be_#");
         response.append (content[i]);
       }
-      else if (operation == bible_logic_format_character_operator ()) {
+      else if (operation == bible_logic::format_character_operator ()) {
         response.append ("#_be_#");
         response.append (content[i]);
       }
@@ -401,8 +402,8 @@ string edit_update (void * webserver_request)
 
   // Test using the Cloud together with client devices with send and receive.
   
-  bool write = AccessBible::BookWrite (webserver_request, username, bible, book);
-  response = Checksum_Logic::send (response, write);
+  bool write = access_bible::book_write (webserver_request, username, bible, book);
+  response = checksum_logic::send (response, write);
 
   // Ready.
   //this_thread::sleep_for(chrono::seconds(5));
