@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -34,9 +34,6 @@ string editone2_verse_url ()
 
 bool editone2_verse_acl (void * webserver_request)
 {
-  if (config::logic::indonesian_cloud_free ()) {
-    return true;
-  }
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
   auto [ read, write ] = access_bible::any (webserver_request);
   return read;
@@ -55,7 +52,7 @@ string editone2_verse (void * webserver_request)
     
     // Only update navigation in case the verse changed.
     // This avoids unnecessary focus operations in the clients.
-    int iverse = convert_to_int (sverse);
+    int iverse = filter::strings::convert_to_int (sverse);
     if (iverse != Ipc_Focus::getVerse (request)) {
       int book = Ipc_Focus::getBook (request);
       int chapter = Ipc_Focus::getChapter (request);
