@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ using namespace std;
 void Editor_Usfm2Html::load (string usfm)
 {
   // Clean up.
-  usfm = filter_string_trim (usfm);
+  usfm = filter::strings::trim (usfm);
   usfm.append ("\n");
   // Separate it into markers and text.
   // Load it into the object.
@@ -106,7 +106,7 @@ string Editor_Usfm2Html::get ()
   
   // Currently the XML library produces hexadecimal character entities.
   // This is unwanted behaviour: Convert them to normal characters.
-  html = convert_xml_character_entities_to_characters (html);
+  html = filter::strings::convert_xml_character_entities_to_characters (html);
   
   // Result.
   return html;
@@ -137,7 +137,7 @@ void Editor_Usfm2Html::preprocess ()
   notes_node = document.append_child ("p");
   notes_value.insert (0, quill_logic_class_prefix_block ());
   notes_node.append_attribute ("class") = notes_value.c_str ();
-  notes_node.text().set(non_breaking_space_u00A0().c_str());
+  notes_node.text().set(filter::strings::non_breaking_space_u00A0().c_str());
 }
 
 
@@ -225,7 +225,7 @@ void Editor_Usfm2Html::process ()
             openTextStyle (style, false);
             string textFollowingMarker = filter::usfm::get_text_following_marker (markers_and_text, markers_and_text_pointer);
             string number = filter::usfm::peek_verse_number (textFollowingMarker);
-            verseStartOffsets [convert_to_int (number)] = static_cast<int>(textLength);
+            verseStartOffsets [filter::strings::convert_to_int (number)] = static_cast<int>(textLength);
             addText (number);
             closeTextStyle (false);
             addText (" ");
@@ -236,7 +236,7 @@ void Editor_Usfm2Html::process ()
               if (pos != string::npos) {
                 textFollowingMarker = textFollowingMarker.substr (pos + number.length());
               }
-              textFollowingMarker = filter_string_ltrim (textFollowingMarker);
+              textFollowingMarker = filter::strings::ltrim (textFollowingMarker);
               markers_and_text [markers_and_text_pointer] = textFollowingMarker;
               markers_and_text_pointer--;
             }
@@ -502,7 +502,7 @@ void Editor_Usfm2Html::addText (string text)
     }
     currentParagraphContent.append (text);
   }
-  textLength += unicode_string_length (text);
+  textLength += filter::strings::unicode_string_length (text);
 }
 
 
@@ -545,7 +545,7 @@ void Editor_Usfm2Html::add_note (string citation, string style, [[maybe_unused]]
   addNoteText (" ");
   
   // Update the text length of the text body, excluding the note.
-  textLength += unicode_string_length (citation);
+  textLength += filter::strings::unicode_string_length (citation);
 }
 
 
@@ -562,7 +562,7 @@ void Editor_Usfm2Html::addNoteText (string text)
   if (!currentNoteTextStyles.empty()) {
     // Take character style(s) as specified in this object.
     string classs;
-    classs = filter_string_implode (currentNoteTextStyles, "0");
+    classs = filter::strings::implode (currentNoteTextStyles, "0");
     classs.insert (0, quill_logic_class_prefix_inline ());
     spanDomElement.append_attribute ("class") = classs.c_str();
   }
@@ -588,7 +588,7 @@ void Editor_Usfm2Html::closeCurrentNote ()
 void Editor_Usfm2Html::addNotelLink (xml_node domNode, int identifier, string style, string text)
 {
   xml_node aDomElement = domNode.append_child ("span");
-  string cls = "i-note" + style + convert_to_string (identifier);
+  string cls = "i-note" + style + filter::strings::convert_to_string (identifier);
   aDomElement.append_attribute ("class") = cls.c_str();
   aDomElement.text ().set (text.c_str());
 }
