@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 #include <bb/logic.h>
 #include <rss/logic.h>
 #include <sendreceive/logic.h>
+using namespace std;
 
 
 string editusfm_save_url ()
@@ -47,7 +48,7 @@ string editusfm_save_url ()
 bool editusfm_save_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
@@ -58,29 +59,29 @@ string editusfm_save (void * webserver_request)
   
   
   string bible = request->post["bible"];
-  int book = convert_to_int (request->post["book"]);
-  int chapter = convert_to_int (request->post["chapter"]);
+  int book = filter::strings::convert_to_int (request->post["book"]);
+  int chapter = filter::strings::convert_to_int (request->post["chapter"]);
   string usfm = request->post["usfm"];
   string checksum = request->post["checksum"];
   string unique_id = request->post ["id"];
 
   
   if (request->post.count ("bible") && request->post.count ("book") && request->post.count ("chapter") && request->post.count ("usfm")) {
-    if (Checksum_Logic::get (usfm) == checksum) {
+    if (checksum_logic::get (usfm) == checksum) {
       usfm = filter_url_tag_to_plus (usfm);
-      usfm = filter_string_trim (usfm);
+      usfm = filter::strings::trim (usfm);
       // Collapse multiple spaces in the USFM into one space.
       // https://github.com/bibledit/cloud/issues/711
-      usfm = filter_string_collapse_whitespace(usfm);
+      usfm = filter::strings::collapse_whitespace(usfm);
       if (!usfm.empty ()) {
-        if (unicode_string_is_valid (usfm)) {
+        if (filter::strings::unicode_string_is_valid (usfm)) {
           string stylesheet = Database_Config_Bible::getEditorStylesheet (bible);
-          vector <BookChapterData> book_chapter_text = usfm_import (usfm, stylesheet);
+          vector <filter::usfm::BookChapterData> book_chapter_text = filter::usfm::usfm_import (usfm, stylesheet);
           if (!book_chapter_text.empty()) {
-            BookChapterData data = book_chapter_text[0];
-            int book_number = data.book;
-            int chapter_number = data.chapter;
-            string chapter_data_to_save = data.data;
+            filter::usfm::BookChapterData data = book_chapter_text[0];
+            int book_number = data.m_book;
+            int chapter_number = data.m_chapter;
+            string chapter_data_to_save = data.m_data;
             if (((book_number == book) || (book_number == 0)) && (chapter_number == chapter)) {
               // The USFM loaded into the editor.
               string ancestor_usfm = getLoadedUsfm2 (webserver_request, bible, book, chapter, unique_id);
@@ -103,7 +104,7 @@ string editusfm_save (void * webserver_request)
               
               // Check on the merge.
               filter_merge_add_book_chapter (conflicts, book, chapter);
-              bible_logic_merge_irregularity_mail ({username}, conflicts);
+              bible_logic::merge_irregularity_mail ({username}, conflicts);
               
               // If the USFM on disk is different from the USFM that was sent to the editor,
               // email the user,
@@ -114,16 +115,16 @@ string editusfm_save (void * webserver_request)
               // Because the user's editor may not yet have loaded this updated Bible text.
               // https://github.com/bibledit/cloud/issues/340
               if (ancestor_usfm != server_usfm) {
-                bible_logic_recent_save_email (bible, book, chapter, username, ancestor_usfm, server_usfm);
+                bible_logic::recent_save_email (bible, book, chapter, username, ancestor_usfm, server_usfm);
               }
               
              
               // Check on write access.
-              if (AccessBible::BookWrite (request, string(), bible, book)) {
+              if (access_bible::book_write (request, string(), bible, book)) {
                 // Safely store the chapter.
                 string explanation;
-                string message = usfm_safely_store_chapter (request, bible, book, chapter, chapter_data_to_save, explanation);
-                bible_logic_unsafe_save_mail (message, explanation, username, chapter_data_to_save, book, chapter);
+                string message = filter::usfm::safely_store_chapter (request, bible, book, chapter, chapter_data_to_save, explanation);
+                bible_logic::unsafe_save_mail (message, explanation, username, chapter_data_to_save, book, chapter);
                 if (message.empty()) {
 #ifndef HAVE_CLIENT
                   // Server configuration: Store details for the user's changes.
