@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <sync/logic.h>
 #include <client/logic.h>
 #include <locale/translate.h>
+using namespace std;
 
 
 void email_send ()
@@ -121,7 +122,7 @@ void email_send ()
         for (auto id2 : ids) {
           database_mail.postpone (id2);
         }
-        Database_Logs::log ("Postponing sending " + convert_to_string (ids.size()) + " emails", Filter_Roles::manager ());
+        Database_Logs::log ("Postponing sending " + filter::strings::convert_to_string (ids.size()) + " emails", Filter_Roles::manager ());
         break;
       } else {
         database_mail.postpone (id);
@@ -145,7 +146,7 @@ struct upload_status {
 #else
 static size_t payload_source (void *ptr, size_t size, size_t nmemb, void *userp)
 {
-  struct upload_status *upload_ctx = (struct upload_status *)userp;
+  upload_status *upload_ctx = static_cast <upload_status *> (userp);
   const char *data;
 
   if((size == 0) || (nmemb == 0) || ((size*nmemb) < 1)) {
@@ -179,7 +180,7 @@ string email_send ([[maybe_unused]] string to_mail,
   // Truncate huge emails because libcurl crashes on it.
   size_t length = body.length ();
   if (length > 100000) {
-    body = "This email was " + convert_to_string (length) + " bytes long. It was too long, and could not be sent.";
+    body = "This email was " + filter::strings::convert_to_string (length) + " bytes long. It was too long, and could not be sent.";
   }
   
   // Deal with empty subject.
@@ -195,7 +196,7 @@ string email_send ([[maybe_unused]] string to_mail,
   Sync_Logic sync_logic = Sync_Logic (&request);
 
   map <string, string> post;
-  post ["n"] = bin2hex (to_name);
+  post ["n"] = filter::strings::bin2hex (to_name);
   post ["s"] = subject;
   post ["b"] = body;
 
@@ -219,15 +220,15 @@ string email_send ([[maybe_unused]] string to_mail,
   
   CURL *curl;
   CURLcode res = CURLE_OK;
-  struct curl_slist *recipients = NULL;
-  struct upload_status upload_ctx;
+  curl_slist * recipients {nullptr};
+  upload_status upload_ctx;
 
   upload_ctx.lines_read = 0;
 
   int seconds = filter::date::seconds_since_epoch ();
   payload_text.clear();
   string payload;
-  payload = "Date: " + convert_to_string (filter::date::numerical_year (seconds)) + "/" + convert_to_string (filter::date::numerical_month (seconds)) + "/" + convert_to_string (filter::date::numerical_month_day (seconds)) + " " + convert_to_string (filter::date::numerical_hour (seconds)) + ":" + convert_to_string (filter::date::numerical_minute (seconds)) + "\n";
+  payload = "Date: " + filter::strings::convert_to_string (filter::date::numerical_year (seconds)) + "/" + filter::strings::convert_to_string (filter::date::numerical_month (seconds)) + "/" + filter::strings::convert_to_string (filter::date::numerical_month_day (seconds)) + " " + filter::strings::convert_to_string (filter::date::numerical_hour (seconds)) + ":" + filter::strings::convert_to_string (filter::date::numerical_minute (seconds)) + "\n";
   payload_text.push_back (payload);
   payload = "To: <" + to_mail + "> " + to_name + "\n";
   payload_text.push_back (payload);
@@ -236,7 +237,7 @@ string email_send ([[maybe_unused]] string to_mail,
   string site = from_mail;
   size_t pos = site.find ("@");
   if (pos != string::npos) site = site.substr (pos);
-  payload = "Message-ID: <" + md5 (convert_to_string (filter_string_rand (0, 1000000))) + site + ">\n";
+  payload = "Message-ID: <" + md5 (filter::strings::convert_to_string (filter::strings::rand (0, 1000000))) + site + ">\n";
   payload_text.push_back (payload);
   payload = "Subject: " + subject + "\n";
   payload_text.push_back (payload);
@@ -261,9 +262,9 @@ string email_send ([[maybe_unused]] string to_mail,
   payload_text.push_back ("<meta charset=\"utf-8\" />\n");
   payload_text.push_back ("</head>\n");
   payload_text.push_back ("<body>\n");
-  vector <string> bodylines = filter_string_explode (body, '\n');
+  vector <string> bodylines = filter::strings::explode (body, '\n');
   for (auto & line : bodylines) {
-    if (filter_string_trim (line).empty ()) payload_text.push_back (" ");
+    if (filter::strings::trim (line).empty ()) payload_text.push_back (" ");
     else payload_text.push_back (line);
     payload_text.push_back ("\n");
   }
@@ -295,7 +296,7 @@ string email_send ([[maybe_unused]] string to_mail,
    * of using CURLUSESSL_TRY here, because if TLS upgrade fails, the transfer
    * will continue anyway - see the security discussion in the libcurl
    * tutorial for more details. */
-  if (port != "25") curl_easy_setopt(curl, CURLOPT_USE_SSL, (long)CURLUSESSL_ALL);
+  if (port != "25") curl_easy_setopt(curl, CURLOPT_USE_SSL, static_cast<long>(CURLUSESSL_ALL));
 
   /* If your server doesn't have a valid certificate, then you can disable
    * part of the Transport Layer Security protection by setting the
@@ -363,7 +364,7 @@ string email_send ([[maybe_unused]] string to_mail,
 void email_schedule (string to, string subject, string body, int time)
 {
   // Schedule the mail for sending.
-  Database_Mail database_mail (NULL);
+  Database_Mail database_mail (nullptr);
   database_mail.send (to, subject, body, time);
   // Schedule a task to send the scheduled mail right away.
   tasks_logic_queue (SENDEMAIL);
