@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -60,17 +60,17 @@ int filter_memory_percentage_available ()
     int memtotal = 0;
     pos = meminfo.find ("MemTotal");
     if (pos != string::npos) {
-      memtotal = convert_to_int (meminfo.substr (pos + 15));
+      memtotal = filter::strings::convert_to_int (meminfo.substr (pos + 15));
     }
     int memfree = 0;
     pos = meminfo.find ("MemFree");
     if (pos != string::npos) {
-      memfree = convert_to_int (meminfo.substr (pos + 15));
+      memfree = filter::strings::convert_to_int (meminfo.substr (pos + 15));
     }
     int cached = 0;
     pos = meminfo.find ("Cached");
     if (pos != string::npos) {
-      cached = convert_to_int (meminfo.substr (pos + 15));
+      cached = filter::strings::convert_to_int (meminfo.substr (pos + 15));
     }
     return (memfree + cached) * 100 / memtotal;
   }
