@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -57,7 +57,7 @@ void Html_Header::search_back_link (string url, string text)
 
 void Html_Header::create (const vector <pair <string, string> > & breadcrumbs)
 {
-  Html_Text * html_text = static_cast<Html_Text *>(m_html_text);
+  HtmlText * html_text = static_cast<HtmlText *>(m_html_text);
   xml_node tableElement = html_text->new_table ();
   xml_node tableRowElement = html_text->new_table_row (tableElement);
   xml_node tableDataElement = html_text->new_table_data (tableRowElement);
