@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,6 +21,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <config/libraries.h>
 
-string index_listing_url (string url);
-bool index_listing_acl (void * webserver_request, string url);
-string index_listing (void * webserver_request, string url);
+std::string index_listing_url (std::string url);
+bool index_listing_acl (void * webserver_request, std::string url);
+std::string index_listing (void * webserver_request, std::string url);
