@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include <filter/usfm.h>
 #include <database/navigation.h>
 #include <webserver/request.h>
+using namespace std;
 
 
 // Deals with the consultation notes stuff.
@@ -31,7 +32,7 @@ void Ipc_Notes::open (void * webserver_request, int identifier)
 {
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   string user = request->session_logic()->currentUser ();
-  request->database_ipc()->storeMessage (user, "", "opennote", convert_to_string (identifier));
+  request->database_ipc()->storeMessage (user, "", "opennote", filter::strings::convert_to_string (identifier));
 }
 
 
@@ -39,7 +40,7 @@ int Ipc_Notes::get (void * webserver_request)
 {
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Ipc_Message data = request->database_ipc()->getNote ();
-  return convert_to_int (data.message);
+  return filter::strings::convert_to_int (data.message);
 }
 
 
@@ -63,7 +64,7 @@ bool Ipc_Notes::alive (void * webserver_request, bool set, bool alive)
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   string user = request->session_logic()->currentUser ();
   if (set) {
-    request->database_ipc()->storeMessage (user, "", "notesalive", convert_to_string (alive));
+    request->database_ipc()->storeMessage (user, "", "notesalive", filter::strings::convert_to_string (alive));
   } else {
     return request->database_ipc()->getNotesAlive ();
   }
