@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ string jobs_index (void * webserver_request)
   
   Assets_View view;
 
-  int id = convert_to_int (request->query ["id"]);
+  int id = filter::strings::convert_to_int (request->query ["id"]);
 
   // Get information about this job.
   Database_Jobs database_jobs = Database_Jobs ();
