@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -36,6 +36,8 @@ extern "C" {
   void bibledit_log (const char * message);
   void bibledit_run_on_chrome_os ();
   const char * bibledit_disable_selection_popup_chrome_os ();
+  const char * bibledit_get_reference_for_accordance ();
+  void bibledit_put_reference_from_accordance (const char * reference);
 
 #ifdef __cplusplus
 }
