@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -23,4 +23,4 @@
 
 const char * manage_exports_url ();
 bool manage_exports_acl (void * webserver_request);
-string manage_exports (void * webserver_request);
+std::string manage_exports (void * webserver_request);
