@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <assets/header.h>
 #include <dialog/entry.h>
 #include <dialog/list.h>
+#include <dialog/list2.h>
 #include <filter/roles.h>
 #include <filter/url.h>
 #include <filter/string.h>
@@ -36,6 +37,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/login.h>
 #include <database/noteassignment.h>
 #include <access/user.h>
+#include <access/logic.h>
 #include <locale/translate.h>
 #include <notes/logic.h>
 #include <menu/logic.h>
@@ -76,6 +78,23 @@ string manage_users (void * webserver_request)
 
 
   int myLevel = request->session_logic ()->currentLevel ();
+
+
+  // Set the default new user role.
+  if (request->post.count ("defaultacl")) {
+    int defaultacl = filter::strings::convert_to_int (request->post ["defaultacl"]);
+    Database_Config_General::setDefaultNewUserAccessLevel(defaultacl);
+    assets_page::success (translate("The default new user is changed."));
+  }
+
+
+  // Set the chosen default new user role on the option HTML tag.
+  string default_acl = filter::strings::convert_to_string (Database_Config_General::getDefaultNewUserAccessLevel ());
+  string default_acl_html;
+  default_acl_html = Options_To_Select::add_selection ("Guest", filter::strings::convert_to_string(Filter_Roles::guest()), default_acl_html);
+  default_acl_html = Options_To_Select::add_selection ("Member", filter::strings::convert_to_string(Filter_Roles::member()), default_acl_html);
+  view.set_variable ("defaultacloptags", Options_To_Select::mark_selected (default_acl, default_acl_html));
+  view.set_variable ("defaultacl", default_acl);
   
   
   // New user creation.
@@ -89,7 +108,31 @@ string manage_users (void * webserver_request)
     if (request->database_users ()->usernameExists (user)) {
       page += assets_page::error (translate("User already exists"));
     } else {
-      request->database_users ()->add_user(user, user, Filter_Roles::member (), "");
+
+      // Set the role of the new created user, it is set as member if no
+      // default has been set by an administrator.
+      int role = Database_Config_General::getDefaultNewUserAccessLevel ();
+      request->database_users ()->add_user(user, user, role, "");
+
+      // Set default privileges on new created user.
+      set <string> defusers = access_logic::default_privilege_usernames ();
+      vector <int> privileges = {PRIVILEGE_VIEW_RESOURCES, PRIVILEGE_VIEW_NOTES, PRIVILEGE_CREATE_COMMENT_NOTES};
+      auto default_username = next(defusers.begin(), (unsigned)(long)(unsigned)role + 1);
+      for (auto & privilege : privileges) {
+        bool state = DatabasePrivileges::get_feature (*default_username, privilege);
+        DatabasePrivileges::set_feature (user, privilege, state);
+      }
+
+      bool deletenotes = request->database_config_user ()->getPrivilegeDeleteConsultationNotesForUser (*default_username);
+      bool useadvancedmode = request->database_config_user ()->getPrivilegeUseAdvancedModeForUser (*default_username);
+      bool editstylesheets = request->database_config_user ()->getPrivilegeSetStylesheetsForUser (*default_username);
+
+      if (deletenotes) request->database_config_user ()->setPrivilegeDeleteConsultationNotesForUser (user, 1);
+      if (useadvancedmode) request->database_config_user ()->setPrivilegeUseAdvancedModeForUser (user, 1);
+      if (editstylesheets) request->database_config_user ()->setPrivilegeSetStylesheetsForUser (user, 1);
+
+      page += assets_page::error (*default_username);
+
       user_logic_store_account_creation (user);
       user_updated = true;
       page += assets_page::success (translate("User created"));
@@ -131,13 +174,13 @@ string manage_users (void * webserver_request)
       dialog_list.add_query ("user", objectUsername);
       for (int i = Filter_Roles::lowest (); i <= Filter_Roles::highest (); i++) {
         if (i <= myLevel) {
-          dialog_list.add_row (Filter_Roles::text (i), "level", convert_to_string (i));
+          dialog_list.add_row (Filter_Roles::text (i), "level", filter::strings::convert_to_string (i));
         }
       }
       page += dialog_list.run ();
       return page;
     } else {
-      request->database_users ()->set_level (objectUsername, convert_to_int (level));
+      request->database_users ()->set_level (objectUsername, filter::strings::convert_to_int (level));
       user_updated = true;
     }
   }
@@ -186,7 +229,7 @@ string manage_users (void * webserver_request)
       assets_page::success (translate("The user has been granted access to this Bible"));
       // Write access depends on whether it's a translator role or higher.
       bool write = (objectUserLevel >= Filter_Roles::translator ());
-      Database_Privileges::setBible (objectUsername, addbible, write);
+      DatabasePrivileges::set_bible (objectUsername, addbible, write);
       user_updated = true;
       privileges_updated = true;
     }
@@ -196,7 +239,7 @@ string manage_users (void * webserver_request)
   // Remove Bible from user.
   if (request->query.count ("removebible")) {
     string removebible = request->query ["removebible"];
-    Database_Privileges::removeBibleBook (objectUsername, removebible, 0);
+    DatabasePrivileges::remove_bible_book (objectUsername, removebible, 0);
     user_updated = true;
     privileges_updated = true;
     assets_page::success (translate("The user no longer has access to this Bible"));
@@ -245,7 +288,7 @@ string manage_users (void * webserver_request)
     
     // Display emoji to delete this account.
     tbody << "<td>";
-    tbody << "<a href=" << quoted("?user=" + username + "&delete") << ">" << emoji_wastebasket () << "</a> " << username;
+    tbody << "<a href=" << quoted("?user=" + username + "&delete") << ">" << filter::strings::emoji_wastebasket () << "</a> " << username;
     tbody << "</td>";
 
     // Divider.
@@ -283,17 +326,17 @@ string manage_users (void * webserver_request)
     if (enabled) {
       if (objectUserLevel < Filter_Roles::manager ()) {
         for (auto & bible : allbibles) {
-          bool exists = Database_Privileges::getBibleBookExists (username, bible, 0);
+          bool exists = DatabasePrivileges::get_bible_book_exists (username, bible, 0);
           if (exists) {
-            auto [ read, write ] = Database_Privileges::getBible (username, bible);
+            auto [ read, write ] = DatabasePrivileges::get_bible (username, bible);
             if  (objectUserLevel >= Filter_Roles::translator ()) write = true;
-            tbody << "<a href=" << quoted ("?user=" + username + "&removebible=" + bible) << ">" << emoji_wastebasket () << "</a>";
+            tbody << "<a href=" << quoted ("?user=" + username + "&removebible=" + bible) << ">" << filter::strings::emoji_wastebasket () << "</a>";
             tbody << "<a href=" << quoted("/bible/settings?bible=" + bible) << ">" << bible << "</a>";
             tbody << "<a href=" << quoted("write?user=" + username + "&bible=" + bible) << ">";
             int readwritebooks = 0;
             vector <int> books = request->database_bibles ()->getBooks (bible);
             for (auto book : books) {
-              Database_Privileges::getBibleBook (username, bible, book, read, write);
+              DatabasePrivileges::get_bible_book (username, bible, book, read, write);
               if (write) readwritebooks++;
             }
             tbody << "(" << readwritebooks << "/" << books.size () << ")";
@@ -306,7 +349,7 @@ string manage_users (void * webserver_request)
         // Managers and higher roles have access to all Bibles.
         tbody << "(" << translate ("all") << ")";
       } else {
-        tbody << "<a href=" << quoted("?user=" + username + "&addbible=") << ">" << emoji_heavy_plus_sign () << "</a>";
+        tbody << "<a href=" << quoted("?user=" + username + "&addbible=") << ">" << filter::strings::emoji_heavy_plus_sign () << "</a>";
       }
     }
     tbody << "</td>";
@@ -361,9 +404,7 @@ string manage_users (void * webserver_request)
     view.enable_zone ("local");
   }
 
-  if (config::logic::indonesian_cloud_free ()) {
-    view.enable_zone("accounts");
-  }
+  if (request->session_logic()->currentLevel () == Filter_Roles::highest ()) view.enable_zone ("admin_settings");
 
   page += view.render ("manage", "users");
 
