@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -108,18 +108,18 @@ using namespace std;
 
 string menu_logic_href (string href)
 {
-  href = filter_string_str_replace ("?", "__q__", href);
-  href = filter_string_str_replace ("&", "__a__", href);
-  href = filter_string_str_replace ("=", "__i__", href);
+  href = filter::strings::replace ("?", "__q__", href);
+  href = filter::strings::replace ("&", "__a__", href);
+  href = filter::strings::replace ("=", "__i__", href);
   return href;
 }
 
 
 string menu_logic_click (string item)
 {
-  item = filter_string_str_replace ("__q__", "?", item);
-  item = filter_string_str_replace ("__a__", "&", item);
-  item = filter_string_str_replace ("__i__", "=", item);
+  item = filter::strings::replace ("__q__", "?", item);
+  item = filter::strings::replace ("__a__", "&", item);
+  item = filter::strings::replace ("__i__", "=", item);
   Database_Config_General::setLastMenuClick (item);
   return item;
 }
@@ -189,7 +189,7 @@ string menu_logic_main_categories (void * webserver_request, string & tooltip)
 
   // Deal with a situation the user has access to the workspaces.
   if (workspace_index_acl (webserver_request)) {
-    if ((config::logic::default_bibledit_configuration () || config::logic::indonesian_cloud_free ()) && !(config::logic::indonesian_cloud_free_simple ())) {
+    if (config::logic::default_bibledit_configuration ()) {
       string label = translate ("Workspace");
       string tooltip2;
       menu_logic_workspace_category (webserver_request, &tooltip2);
@@ -201,68 +201,38 @@ string menu_logic_main_categories (void * webserver_request, string & tooltip)
   string menutooltip;
   int current_theme_index = request->database_config_user ()->getCurrentTheme ();
   string filename = current_theme_filebased_cache_filename (request->session_identifier);
-  if (config::logic::indonesian_cloud_free_simple ()) {
-    if (database_filebased_cache_exists (filename)) {
-      current_theme_index = convert_to_int (database_filebased_cache_get (filename));
-    } else {
-      database_filebased_cache_put (filename, "1");
-      current_theme_index = 1;
-    }
-  }
   string color = Filter_Css::theme_picker (current_theme_index, 1);
 
   if (!menu_logic_translate_category (webserver_request, &menutooltip).empty ()) {
-    if (config::logic::indonesian_cloud_free_simple ()) {
-      html.push_back (menu_logic_create_item (read_index_url (), "Baca", true, "", color));
-    }
-
-    if ((config::logic::default_bibledit_configuration () || config::logic::indonesian_cloud_free ()) && !(config::logic::indonesian_cloud_free_simple ())) {
+    if (config::logic::default_bibledit_configuration ()) {
       html.push_back (menu_logic_create_item (menu_logic_translate_menu (), menu_logic_translate_text (), false, menutooltip, color));
       tooltipbits.push_back (menu_logic_translate_text ());
     }
   }
   
   if (!menu_logic_search_category (webserver_request, &menutooltip).empty ()) {
-    if (config::logic::indonesian_cloud_free_simple ()) {
-      html.push_back (menu_logic_create_item (resource_index_url (), "Teliti", true, "", color));
-    }
-
-    if ((config::logic::default_bibledit_configuration () || config::logic::indonesian_cloud_free ()) && !(config::logic::indonesian_cloud_free_simple ())) {
+    if (config::logic::default_bibledit_configuration ()) {
       html.push_back (menu_logic_create_item (menu_logic_search_menu (), menu_logic_search_text (), false, menutooltip, color));
       tooltipbits.push_back (menu_logic_search_text ());
     }
   }
 
   if (!menu_logic_tools_category (webserver_request, &menutooltip).empty ()) {
-    if (config::logic::indonesian_cloud_free_simple ()) {
-      menu_logic_workspace_category (webserver_request, &tooltip);
-      html.push_back (menu_logic_create_item (workspace_index_url (), "Baca dan Teliti", true, "", color));
-    }
-
-    if ((config::logic::default_bibledit_configuration () || config::logic::indonesian_cloud_free ()) && !(config::logic::indonesian_cloud_free_simple ())) {
+    if (config::logic::default_bibledit_configuration ()) {
       html.push_back (menu_logic_create_item (menu_logic_tools_menu (), menu_logic_tools_text (), false, menutooltip, color));
       tooltipbits.push_back (menu_logic_tools_text ());
     }
   }
 
   if (!menu_logic_settings_category (webserver_request, &menutooltip).empty ()) {
-    if (config::logic::indonesian_cloud_free_simple ()) {
-      html.push_back (menu_logic_create_item (personalize_index_url (), "⋮", true, "", color));
-    }
-
-
-    if ((config::logic::default_bibledit_configuration () || config::logic::indonesian_cloud_free ()) && !(config::logic::indonesian_cloud_free_simple ())) {
+    if (config::logic::default_bibledit_configuration ()) {
       html.push_back (menu_logic_create_item (menu_logic_settings_menu (), menu_logic_settings_text (), false, menutooltip, color));
       tooltipbits.push_back (menu_logic_settings_text ());
     }
   }
   
   if (!menu_logic_help_category (webserver_request).empty ()) {
-    if (config::logic::indonesian_cloud_free_simple ()) {
-      html.push_back("");
-    }
-
-    if ((config::logic::default_bibledit_configuration () || config::logic::indonesian_cloud_free ()) && !(config::logic::indonesian_cloud_free_simple ())) {
+    if (config::logic::default_bibledit_configuration ()) {
       html.push_back (menu_logic_create_item ("help/index", menu_logic_help_text (), true, menu_logic_help_text (), color));
       tooltipbits.push_back (menu_logic_help_text ());
     }
@@ -298,10 +268,10 @@ string menu_logic_main_categories (void * webserver_request, string & tooltip)
   }
 
   // Create one string of tool tips for this menu item, separated by a vertical bar.
-  tooltip = filter_string_implode (tooltipbits, " | ");
+  tooltip = filter::strings::implode (tooltipbits, " | ");
   
   // Create one string of html that is going to form the menu.
-  return filter_string_implode (html, "\n");
+  return filter::strings::implode (html, "\n");
 }
 
 
@@ -326,14 +296,6 @@ string menu_logic_basic_categories (void * webserver_request)
 
   int current_theme_index = request->database_config_user ()->getCurrentTheme ();
   string filename = current_theme_filebased_cache_filename (request->session_identifier);
-  if (config::logic::indonesian_cloud_free_simple ()) {
-    if (database_filebased_cache_exists (filename)) {
-      current_theme_index = convert_to_int (database_filebased_cache_get (filename));
-    } else {
-      database_filebased_cache_put (filename, "1");
-      current_theme_index = 1;
-    }
-  }
   string color = Filter_Css::theme_picker (current_theme_index, 1);
 
   if (read_index_acl (webserver_request)) {
@@ -367,12 +329,6 @@ string menu_logic_basic_categories (void * webserver_request)
   // put the public feedback into the main menu, rather than in a sub menu.
   // This is the default configuration.
   bool public_feedback_possible { true };
-  // In the Indonesian Cloud Free, there's no public feedback possible,
-  // since the aim is to keep things easy to understand for beginners.
-  // Except when it's the Indonesian Cloud Free Simple.
-  if (config::logic::indonesian_cloud_free ()) {
-    public_feedback_possible = false;
-  }
   if (public_feedback_possible) {
     if (menu_logic_public_or_guest (webserver_request)) {
       if (!public_logic_bibles (webserver_request).empty ()) {
@@ -400,7 +356,7 @@ string menu_logic_basic_categories (void * webserver_request)
   }
 #endif
 
-  return filter_string_implode (html, "\n");
+  return filter::strings::implode (html, "\n");
 }
 
 
@@ -420,7 +376,7 @@ string menu_logic_workspace_category (void * webserver_request, string * tooltip
 
     vector <string> workspaces = workspace_get_names (webserver_request);
     for (size_t i = 0; i < workspaces.size(); i++) {
-      string item = menu_logic_create_item (workspace_index_url () + "?bench=" + convert_to_string (i), workspaces[i], true, "", "");
+      string item = menu_logic_create_item (workspace_index_url () + "?bench=" + filter::strings::convert_to_string (i), workspaces[i], true, "", "");
       // Adds an active class if it is the current workspace.
       if (workspaces[i] == activeWorkspace) {
         size_t startIndex = item.find(R"("><a)");
@@ -431,11 +387,8 @@ string menu_logic_workspace_category (void * webserver_request, string * tooltip
     }
   }
 
-  if (tooltip) tooltip->assign (filter_string_implode (labels, " | "));
-  // Indonesian Cloud Free
-  // The default setting only has one workspace.
-  if (config::logic::indonesian_cloud_free_simple ()) return "";
-  return filter_string_implode (html, "\n");
+  if (tooltip) tooltip->assign (filter::strings::implode (labels, " | "));
+  return filter::strings::implode (html, "\n");
 }
 
 
@@ -509,8 +462,8 @@ string menu_logic_translate_category (void * webserver_request, string * tooltip
     html.insert (html.begin (), menu_logic_translate_text () + ": ");
   }
 
-  if (tooltip) tooltip->assign (filter_string_implode (labels, " | "));
-  return filter_string_implode (html, "\n");
+  if (tooltip) tooltip->assign (filter::strings::implode (labels, " | "));
+  return filter::strings::implode (html, "\n");
 }
 
 
@@ -577,8 +530,8 @@ string menu_logic_search_category (void * webserver_request, string * tooltip)
     html.insert (html.begin (), menu_logic_search_text () + ": ");
   }
   
-  if (tooltip) tooltip->assign (filter_string_implode (labels, " | "));
-  return filter_string_implode (html, "\n");
+  if (tooltip) tooltip->assign (filter::strings::implode (labels, " | "));
+  return filter::strings::implode (html, "\n");
 }
 
 
@@ -700,8 +653,8 @@ string menu_logic_tools_category (void * webserver_request, string * tooltip)
     html.insert (html.begin (), menu_logic_tools_text () + ": ");
   }
   
-  if (tooltip) tooltip->assign (filter_string_implode (tiplabels, " | "));
-  return filter_string_implode (html, "\n");
+  if (tooltip) tooltip->assign (filter::strings::implode (tiplabels, " | "));
+  return filter::strings::implode (html, "\n");
 }
 
 
@@ -931,7 +884,7 @@ string menu_logic_settings_category (void * webserver_request, string * tooltip)
     
     if (label == basic_mode) {
       if (request->session_logic ()->currentLevel () > Filter_Roles::guest ()) {
-        html.push_back (menu_logic_create_item (index_index_url () + convert_to_string ("?mode=basic"), label, true, "", ""));
+        html.push_back (menu_logic_create_item (index_index_url () + filter::strings::convert_to_string ("?mode=basic"), label, true, "", ""));
         tiplabels.push_back (label);
       }
     }
@@ -957,8 +910,8 @@ string menu_logic_settings_category (void * webserver_request, string * tooltip)
     html.insert (html.begin (), menu_logic_settings_text () + " (" + user + "): ");
   }
   
-  if (tooltip) tooltip->assign (filter_string_implode (tiplabels, " | "));
-  return filter_string_implode (html, "\n");
+  if (tooltip) tooltip->assign (filter::strings::implode (tiplabels, " | "));
+  return filter::strings::implode (html, "\n");
 }
 
 
@@ -1024,7 +977,7 @@ string menu_logic_settings_resources_category ([[maybe_unused]] void * webserver
     html.insert (html.begin (), menu_logic_resources_text () + ": ");
   }
   
-  return filter_string_implode (html, "\n");
+  return filter::strings::implode (html, "\n");
 }
 
 
@@ -1042,7 +995,7 @@ string menu_logic_help_category (void * webserver_request)
     html.insert (html.begin (), menu_logic_help_text () + ": ");
   }
   
-  return filter_string_implode (html, "\n");
+  return filter::strings::implode (html, "\n");
 }
 
 
@@ -1252,11 +1205,6 @@ bool menu_logic_editor_enabled (void * webserver_request, bool visual, bool chap
   int selection = 0;
   if (visual) selection = request->database_config_user ()->getFastSwitchVisualEditors ();
   else selection = request->database_config_user ()->getFastSwitchUsfmEditors ();
-  if (config::logic::indonesian_cloud_free ()) {
-    // Show all editors in the Indonesian Cloud Free.
-    if (visual) selection = 0;
-    else selection = 1;
-  }
 
   if (visual) {
     // Check whether the visual chapter or verse editor is active.
