@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_NAVIGATION_UPDATE_H
-#define INCLUDED_NAVIGATION_UPDATE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string navigation_update_url ();
+std::string navigation_update_url ();
 bool navigation_update_acl (void * webserver_request);
-string navigation_update (void * webserver_request);
-
-
-#endif
+std::string navigation_update (void * webserver_request);
