@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 #include <database/logs.h>
 #include <styles/logic.h>
 #include <access/logic.h>
+using namespace std;
 
 
 string notes_actions_url ()
@@ -52,14 +53,14 @@ bool notes_actions_acl (void * webserver_request)
 
 string notes_actions (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   Notes_Logic notes_logic = Notes_Logic (webserver_request);
 
   
   string page;
   Assets_Header header = Assets_Header (translate("Actions"), request);
-  header.setNavigator ();
+  header.set_navigator ();
   page += header.run ();
   Assets_View view;
   string success, error;
@@ -69,11 +70,14 @@ string notes_actions (void * webserver_request)
   int level = request->session_logic()->currentLevel ();
 
   
-  int id;
-  if (request->query.count ("id")) id = convert_to_int (request->query ["id"]);
-  else id = convert_to_int (request->post ["id"]);
+  int id = filter::strings::convert_to_int (request->query ["id"]);
+  if (!id) id = filter::strings::convert_to_int (request->post ["val1"]);
 
   
+  string checkbox = request->post ["checkbox"];
+  bool checked = filter::strings::convert_to_bool (request->post ["checked"]);
+
+
   if (request->query.count ("unsubscribe")) {
     notes_logic.unsubscribe (id);
   }
@@ -113,13 +117,13 @@ string notes_actions (void * webserver_request)
   }
   
   
-  if (request->query.count ("publicnote")) {
-    bool state = database_notes.get_public (id);
-    database_notes.set_public (id, !state);
+  if (checkbox == "public") {
+    database_notes.set_public (id, checked);
+    return "";
   }
 
   
-  view.set_variable ("id", convert_to_string (id));
+  view.set_variable ("id", filter::strings::convert_to_string (id));
   
                       
   string summary = database_notes.get_summary (id);
@@ -132,15 +136,15 @@ string notes_actions (void * webserver_request)
   
 
   vector <string> assignees = database_notes.get_assignees (id);
-  string assigneeblock;
+  stringstream assigneeblock;
   for (auto & assignee : assignees) {
-    assigneeblock.append (assignee);
+    assigneeblock << assignee;
     if (level >= Filter_Roles::manager ()) {
-      assigneeblock.append ("<a href=\"?id=" + convert_to_string (id) + "&unassign=" + assignee + "\"> [" + translate("unassign") + "]</a>");
-      assigneeblock.append (" | ");
+      assigneeblock << "<a href=" << quoted ("?id=" + filter::strings::convert_to_string (id) + "&unassign=" + assignee) << "> [" << translate("unassign") << "]</a>";
+      assigneeblock << " | ";
     }
   }
-  view.set_variable ("assigneeblock", assigneeblock);
+  view.set_variable ("assigneeblock", assigneeblock.str());
   if (level >= Filter_Roles::manager ()) view.enable_zone ("assign");
 
   
@@ -170,24 +174,24 @@ string notes_actions (void * webserver_request)
   if (level >= Filter_Roles::manager ()) view.enable_zone ("rawedit");
   
 
-  if (access_logic_privilege_delete_consultation_notes (webserver_request)) view.enable_zone ("deletenote");
+  if (access_logic::privilege_delete_consultation_notes (webserver_request))
+    view.enable_zone ("deletenote");
   bool marked = database_notes.is_marked_for_deletion (id);
   if (marked) view.enable_zone ("marked");
   else view.enable_zone ("mark");
   
   
-#ifndef HAVE_CLIENT
+#ifdef HAVE_CLOUD
   view.enable_zone ("cloud");
-  string on_off = styles_logic_off_on_inherit_toggle_text (database_notes.get_public (id));
-  view.set_variable ("publicnote", on_off);
+  view.set_variable ("public", filter::strings::get_checkbox_status (database_notes.get_public (id)));
 #endif
   // Roles of translator or higher can edit the public visibility of a note.
-  if (level >= Filter_Roles::translator ()) view.enable_zone ("translator");
+  if (level < Filter_Roles::translator ()) view.set_variable(filter::strings::get_disabled(), filter::strings::get_disabled());
 
   
   view.set_variable ("success", success);
   view.set_variable ("error", error);
   page += view.render ("notes", "actions");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
