@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include <ipc/focus.h>
 #include <navigation/passage.h>
 #include <notes/actions.h>
+using namespace std;
 
 
 string notes_status_n_url ()
@@ -48,7 +49,7 @@ bool notes_status_n_acl (void * webserver_request)
 
 string notes_status_n (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   
   
@@ -58,15 +59,15 @@ string notes_status_n (void * webserver_request)
   Assets_View view;
   
   
-  string statusblock;
+  stringstream statusblock;
   vector <Database_Notes_Text> statuses = database_notes.get_possible_statuses ();
   for (auto & status : statuses) {
-    statusblock.append ("<li><a href=\"bulk?status=" + status.raw + "\">" + status.raw + "</a></li>\n");
+    statusblock << "<li><a href=" << quoted ("bulk?status=" + status.raw) << ">" << status.raw << "</a></li>" << endl;
   }
-  view.set_variable ("statusblock", statusblock);
+  view.set_variable ("statusblock", statusblock.str());
   
   
   page += view.render ("notes", "status-n");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
