@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string notes_summary_url ();
+std::string notes_summary_url ();
 bool notes_summary_acl (void * webserver_request);
-string notes_summary (void * webserver_request);
+std::string notes_summary (void * webserver_request);
