@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ string public_create (void * webserver_request)
   string verse_usfm = filter::usfm::get_verse_text (chapter_usfm, verse);
   string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
   Filter_Text filter_text = Filter_Text (bible);
-  filter_text.html_text_standard = new Html_Text (bible);
+  filter_text.html_text_standard = new HtmlText (bible);
   filter_text.add_usfm_code (verse_usfm);
   filter_text.run (stylesheet);
   string versetext = filter_text.html_text_standard->get_inner_html ();
@@ -81,20 +81,15 @@ string public_create (void * webserver_request)
 
  
   if (request->post.count ("submit")) {
-    string summary = filter_string_trim (request->post["summary"]);
+    string summary = filter::strings::trim (request->post["summary"]);
     if (summary.empty ()) summary = translate ("Feedback");
-    string contents = "<p>" + versetext + "</p>" + filter_string_trim (request->post["contents"]);
+    string contents = "<p>" + versetext + "</p>" + filter::strings::trim (request->post["contents"]);
     int identifier = notes_logic.createNote (bible, book, chapter, verse, summary, contents, false);
     // A note created by a public user is made public to all.
     database_notes.set_public (identifier, true);
     // Subscribe the user to the note.
     // Then the user receives email about any updates made on this note.
     database_notes.subscribe (identifier);
-    // Indonesian Cloud Free
-    // Go to the main read Bible page.
-    if (config::logic::indonesian_cloud_free_simple ()) {
-      redirect_browser (request, read_index_url ());
-    }
     // Go to the main public notes page.
     if (config::logic::default_bibledit_configuration ()) {
       redirect_browser (request, public_index_url ());
@@ -104,9 +99,6 @@ string public_create (void * webserver_request)
 
   
   if (request->post.count ("cancel")) {
-    if (config::logic::indonesian_cloud_free_simple ()) {
-      redirect_browser (request, read_index_url ());
-    }
     if (config::logic::default_bibledit_configuration ()) {
       redirect_browser (request, public_index_url ());
     }
@@ -114,7 +106,7 @@ string public_create (void * webserver_request)
   }
   
   
-  string passage = filter_passage_display (book, chapter, convert_to_string (verse));
+  string passage = filter_passage_display (book, chapter, filter::strings::convert_to_string (verse));
   view.set_variable ("passage", passage);
                                                                                                       
   
