@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_PUBLIC_CREATE_H
-#define INCLUDED_PUBLIC_CREATE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string public_create_url ();
+std::string public_create_url ();
 bool public_create_acl (void * webserver_request);
-string public_create (void * webserver_request);
-
-
-#endif
+std::string public_create (void * webserver_request);
