@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ string resource_comparative1edit (void * webserver_request)
 
   
   string checkbox = request->post ["checkbox"];
-  bool checked = convert_to_bool (request->post ["checked"]);
+  bool checked = filter::strings::convert_to_bool (request->post ["checked"]);
 
   
   bool resource_edited = false;
@@ -197,7 +197,7 @@ string resource_comparative1edit (void * webserver_request)
     // Store the list of comparative resources for download by the client devices.
     {
       string path = resource_logic_comparative_resources_list_path ();
-      filter_url_file_put_contents (path, filter_string_implode (resources, "\n"));
+      filter_url_file_put_contents (path, filter::strings::implode (resources, "\n"));
     }
   }
   
@@ -209,9 +209,9 @@ string resource_comparative1edit (void * webserver_request)
   view.set_variable ("update", update);
   view.set_variable ("remove", remove);
   view.set_variable ("replace", replace);
-  view.set_variable ("diacritics", get_checkbox_status (diacritics));
-  view.set_variable ("casefold", get_checkbox_status (casefold));
-  view.set_variable ("cache", get_checkbox_status (cache));
+  view.set_variable ("diacritics", filter::strings::get_checkbox_status (diacritics));
+  view.set_variable ("casefold", filter::strings::get_checkbox_status (casefold));
+  view.set_variable ("cache", filter::strings::get_checkbox_status (cache));
   page += view.render ("resource", "comparative1edit");
   page += assets_page::footer ();
   return page;
