@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,4 +21,4 @@
 
 #include <config/libraries.h>
 
-void convert_bible_to_resource (string bible);
+void convert_bible_to_resource (std::string bible);
