@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -108,7 +108,7 @@ string resource_images (void * webserver_request)
     resourceblock.push_back ("</a>");
     resourceblock.push_back ("</p>");
   }
-  view.set_variable ("resourceblock", filter_string_implode (resourceblock, "\n"));
+  view.set_variable ("resourceblock", filter::strings::implode (resourceblock, "\n"));
 
    
   view.set_variable ("success", success);
