@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -81,7 +81,7 @@ string resource_studylight (void * webserver_request)
   
   string path = resource_logic_study_light_module_list_path ();
   string moduleblock = filter_url_file_get_contents (path);
-  vector <string> lines = filter_string_explode (moduleblock, '\n');
+  vector <string> lines = filter::strings::explode (moduleblock, '\n');
   moduleblock.clear ();
   for (auto line : lines) {
     moduleblock.append ("<p>");
