@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -26,12 +26,21 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/date.h>
 #include <database/config/general.h>
 #include <database/config/bible.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifndef HAVE_PUGIXML
 #include <pugixml/pugixml.hpp>
+#endif
+#ifdef HAVE_PUGIXML
+#include <pugixml.hpp>
+#endif
+#pragma GCC diagnostic pop
 #include <locale/translate.h>
 #include <tasks/logic.h>
 #include <rss/feed.h>
-
-
+using namespace std;
 using namespace pugi;
 
 
@@ -75,15 +84,15 @@ void rss_logic_schedule_update (string user, string bible, int book, int chapter
   if (!Database_Config_Bible::getSendChangesToRSS (bible)) return;
   
   // Mould the USFM into one line.
-  oldusfm = filter_string_str_replace ("\n", rss_logic_new_line (), oldusfm);
-  newusfm = filter_string_str_replace ("\n", rss_logic_new_line (), newusfm);
+  oldusfm = filter::strings::replace ("\n", rss_logic_new_line (), oldusfm);
+  newusfm = filter::strings::replace ("\n", rss_logic_new_line (), newusfm);
   
   // Schedule it.
   vector <string> parameters;
   parameters.push_back (user);
   parameters.push_back (bible);
-  parameters.push_back (convert_to_string (book));
-  parameters.push_back (convert_to_string (chapter));
+  parameters.push_back (filter::strings::convert_to_string (book));
+  parameters.push_back (filter::strings::convert_to_string (chapter));
   parameters.push_back (oldusfm);
   parameters.push_back (newusfm);
   tasks_logic_queue (RSSFEEDUPDATECHAPTER, parameters);
@@ -97,8 +106,8 @@ void rss_logic_execute_update (string user, string bible, int book, int chapter,
   if (oldusfm == newusfm) return;
 
   // Mould the USFM back into its original format with new lines.
-  oldusfm = filter_string_str_replace (rss_logic_new_line (), "\n", oldusfm);
-  newusfm = filter_string_str_replace (rss_logic_new_line (), "\n", newusfm);
+  oldusfm = filter::strings::replace (rss_logic_new_line (), "\n", oldusfm);
+  newusfm = filter::strings::replace (rss_logic_new_line (), "\n", newusfm);
 
   // Whether to include the author in the RSS feed.
   // For security reasons this can be set off.
@@ -113,16 +122,16 @@ void rss_logic_execute_update (string user, string bible, int book, int chapter,
   string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
 
   // Get the combined verse numbers in old and new USFM.
-  vector <int> old_verse_numbers = usfm_get_verse_numbers (oldusfm);
-  vector <int> new_verse_numbers = usfm_get_verse_numbers (newusfm);
+  vector <int> old_verse_numbers = filter::usfm::get_verse_numbers (oldusfm);
+  vector <int> new_verse_numbers = filter::usfm::get_verse_numbers (newusfm);
   vector <int> verses = old_verse_numbers;
   verses.insert (verses.end (), new_verse_numbers.begin (), new_verse_numbers.end ());
-  verses = array_unique (verses);
+  verses = filter::strings::array_unique (verses);
   sort (verses.begin(), verses.end());
 
   for (auto verse : verses) {
-    string old_verse_usfm = usfm_get_verse_text (oldusfm, verse);
-    string new_verse_usfm = usfm_get_verse_text (newusfm, verse);
+    string old_verse_usfm = filter::usfm::get_verse_text (oldusfm, verse);
+    string new_verse_usfm = filter::usfm::get_verse_text (newusfm, verse);
     if (old_verse_usfm != new_verse_usfm) {
       Filter_Text filter_text_old = Filter_Text (bible);
       Filter_Text filter_text_new = Filter_Text (bible);
@@ -136,7 +145,7 @@ void rss_logic_execute_update (string user, string bible, int book, int chapter,
       string new_text = filter_text_new.text_text->get ();
       if (old_text != new_text) {
         string modification = filter_diff_diff (old_text, new_text);
-        titles.push_back (filter_passage_display (book, chapter, convert_to_string (verse)));
+        titles.push_back (filter_passage_display (book, chapter, filter::strings::convert_to_string (verse)));
         authors.push_back (user);
         descriptions.push_back ("<div>" + modification + "</div>");
       }
@@ -158,7 +167,7 @@ void rss_logic_update_xml (vector <string> titles, vector <string> authors, vect
 {
   int seconds = filter::date::seconds_since_epoch ();
   string rfc822time = filter::date::rfc822 (seconds);
-  string guid = convert_to_string (seconds);
+  string guid = filter::strings::convert_to_string (seconds);
   bool document_updated = false;
   xml_document document;
   string path = rss_logic_xml_path ();
@@ -191,7 +200,7 @@ void rss_logic_update_xml (vector <string> titles, vector <string> authors, vect
   xml_node channel = rss_node.child ("channel");
   for (size_t i = 0; i < titles.size(); i++) {
     xml_node item = channel.append_child ("item");
-    string guid2 = guid + convert_to_string (i);
+    string guid2 = guid + filter::strings::convert_to_string (i);
     xml_node guid_node = item.append_child ("guid");
     guid_node.append_attribute ("isPermaLink") = "false";
     guid_node.text () = guid2.c_str();
