@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -68,27 +68,27 @@ string search_replacepre (void * webserver_request)
   
   
   // Get the plain text.
-  string text = search_logic_get_bible_verse_text (bible, book, chapter, convert_to_int (verse));
+  string text = search_logic_get_bible_verse_text (bible, book, chapter, filter::strings::convert_to_int (verse));
   
   
   // Clickable passage.
   string link = filter_passage_link_for_opening_editor_at (book, chapter, verse);
   
   
-  string oldtext = filter_string_markup_words ({searchfor}, text);
+  string oldtext = filter::strings::markup_words ({searchfor}, text);
   
 
   string newtext;
   if (casesensitive) {
-    newtext = filter_string_str_replace (searchfor, replacewith, text);
+    newtext = filter::strings::replace (searchfor, replacewith, text);
   } else {
     newtext = text;
-    vector <string> needles = filter_string_search_needles (searchfor, text);
+    vector <string> needles = filter::strings::search_needles (searchfor, text);
     for (auto & needle : needles) {
-      newtext = filter_string_str_replace (needle, replacewith, newtext);
+      newtext = filter::strings::replace (needle, replacewith, newtext);
     }
   }
-  if (replacewith != "") newtext = filter_string_markup_words ({replacewith}, newtext);
+  if (replacewith != "") newtext = filter::strings::markup_words ({replacewith}, newtext);
   
   
   // Check whether the user has write access to the book.
@@ -100,7 +100,7 @@ string search_replacepre (void * webserver_request)
   string output;
   output.append ("<div id=\"" + id + "\">\n");
   output.append ("<p>");
-  if (write) output.append ("<a href=\"replace\"> ✔ </a> <a href=\"delete\">" + emoji_wastebasket () + "</a> ");
+  if (write) output.append ("<a href=\"replace\"> ✔ </a> <a href=\"delete\">" + filter::strings::emoji_wastebasket () + "</a> ");
   output.append (link);
   output.append ("</p>\n");
   output.append ("<p>" + oldtext + "</p>\n");
