@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -30,6 +30,12 @@ $(document).ready (function () {
     startSearch ();
   });
   identifier = Math.floor ((Math.random () * 1000000) + 1000000);
+  // Listens for bibleselect option tags value change to update the active Bible.
+  var bibleSelectionElement = document.querySelector ("#bibleselect");
+  bibleSelectionElement.addEventListener ('change', () => {
+    $.post ("search2", { bibleselect: bibleSelectionElement.value })
+      .done (function() { window.location.reload () });
+  });
 });
 
 
