@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/roles.h>
 #include <config/globals.h>
 #include <user/logic.h>
+using namespace std;
 
 
 // The username and password for a demo installation, and for a disconnected client installation
@@ -131,7 +132,7 @@ bool Session_Logic::openAccess ()
 string Session_Logic::remoteAddress ()
 {
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  vector <string> blocks = filter_string_explode (request->remote_address, '.');
+  vector <string> blocks = filter::strings::explode (request->remote_address, '.');
   string address;
   size_t num_blocks = static_cast<size_t> (abs (check_ip_blocks));
   if (num_blocks > blocks.size ()) num_blocks = blocks.size ();
