@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -24,18 +24,20 @@
 class Styles_Css
 {
 public:
-  Styles_Css (void * webserver_request_in, string stylesheet_in);
+  Styles_Css (void * webserver_request, const std::string & stylesheet);
+  Styles_Css(const Styles_Css&) = delete;
+  Styles_Css operator=(const Styles_Css&) = delete;
   void editor ();
   void exports ();
   void generate ();
-  string css (string path = "");
-  void customize (const string& bible);
+  std::string css (std::string path = std::string());
+  void customize (const std::string& bible);
 private:
-  void * webserver_request;
-  string stylesheet;
-  vector <string> code;
-  bool editor_enabled = false; // Whether to generate CSS for the Bible text editor.
-  bool exports_enabled = false; // Whether to generate CSS for exported Bibles.
+  void * m_webserver_request {nullptr};
+  std::string m_stylesheet {};
+  std::vector <std::string> m_code {};
+  bool editor_enabled {false}; // Whether to generate CSS for the Bible text editor.
+  bool exports_enabled {false}; // Whether to generate CSS for exported Bibles.
   void evaluate (void * database_styles_item);
   void add (void * database_styles_item, bool paragraph, bool keepwithnext);
   void add_exports_styles ();
