@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -56,26 +56,26 @@ string styles_indexm (void * webserver_request)
 {
   Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
-  string page;
+  string page {};
   
   Assets_Header header = Assets_Header (translate("Styles"), webserver_request);
   header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
   
-  Assets_View view;
+  Assets_View view {};
   
-  Database_Styles database_styles;
+  Database_Styles database_styles {};
   
-  string username = request->session_logic ()->currentUser ();
-  int userlevel = request->session_logic ()->currentLevel ();
+  string username {request->session_logic ()->currentUser ()};
+  int userlevel {request->session_logic ()->currentLevel ()};
   
   if (request->post.count ("new")) {
-    string name = request->post["entry"];
+    string name {request->post["entry"]};
     // Remove spaces at the ends of the name for the new stylesheet.
     // Because predictive keyboards can add a space to the name,
     // and the stylesheet system is not built for whitespace at the start / end of the name of the stylesheet.
-    name = filter_string_trim (name);
-    vector <string> existing = database_styles.getSheets ();
+    name = filter::strings::trim (name);
+    vector <string> existing {database_styles.getSheets ()};
     if (find (existing.begin(), existing.end (), name) != existing.end ()) {
       page += assets_page::error (translate("This stylesheet already exists"));
     } else {
@@ -86,37 +86,37 @@ string styles_indexm (void * webserver_request)
     }
   }
   if (request->query.count ("new")) {
-    Dialog_Entry dialog_entry = Dialog_Entry ("indexm", translate("Please enter the name for the new stylesheet"), "", "new", "");
+    Dialog_Entry dialog_entry = Dialog_Entry ("indexm", translate("Please enter the name for the new stylesheet"), string(), "new", string());
     page += dialog_entry.run();
     return page;
   }
   
   if (request->query.count ("delete")) {
-    string del = request->query ["delete"];
-    if (del != "") {
-      string confirm = request->query ["confirm"];
+    string del {request->query ["delete"]};
+    if (!del.empty()) {
+      string confirm {request->query ["confirm"]};
       if (confirm == "yes") {
         bool write = database_styles.hasWriteAccess (username, del);
         if (userlevel >= Filter_Roles::admin ()) write = true;
         if (write) {
           database_styles.deleteSheet (del);
-          database_styles.revokeWriteAccess ("", del);
+          database_styles.revokeWriteAccess (string(), del);
           page += assets_page::success (translate("The stylesheet has been deleted"));
         }
-      } if (confirm == "") {
+      } if (confirm.empty()) {
         Dialog_Yes dialog_yes = Dialog_Yes ("indexm", translate("Would you like to delete this stylesheet?"));
         dialog_yes.add_query ("delete", del);
         page += dialog_yes.run ();
         return page;
       }
     }
-  
   }
+ 
   // Delete empty sheet that may have been there.
-  database_styles.deleteSheet ("");
+  database_styles.deleteSheet (string());
 
   vector <string> sheets = database_styles.getSheets();
-  stringstream sheetblock;
+  stringstream sheetblock {};
   for (auto & sheet : sheets) {
     sheetblock << "<p>";
     sheetblock << sheet;
