@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -72,17 +72,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define ParagraphSubtypeNormalParagraph            3 
 
 
-#define PeripheralSubtypePublication       0 
-#define PeripheralSubtypeTableOfContents   1 
-#define PeripheralSubtypePreface           2 
-#define PeripheralSubtypeIntroduction      3 
-#define PeripheralSubtypeGlossary          4 
-#define PeripheralSubtypeConcordance       5 
-#define PeripheralSubtypeIndex             6 
-#define PeripheralSubtypeMapIndex          7 
-#define PeripheralSubtypeCover             8 
-#define PeripheralSubtypeSpine             9 
-
+#define PeripheralSubtypePublication     0
+#define PeripheralSubtypeTableOfContents 1
+#define PeripheralSubtypePreface         2
+#define PeripheralSubtypeIntroduction    3
+#define PeripheralSubtypeGlossary        4
+#define PeripheralSubtypeConcordance     5
+#define PeripheralSubtypeIndex           6
+#define PeripheralSubtypeMapIndex        7
+#define PeripheralSubtypeCover           8
+#define PeripheralSubtypeSpine           9
+#define PeripheralSubtypeGeneral        10
 
 #define TableElementSubtypeRow             0 
 #define TableElementSubtypeHeading         1 
@@ -165,31 +165,31 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define EndNotePositionAtMarker   2 
 
 
-string styles_logic_standard_sheet ();
-string styles_logic_category_text (string category);
-string styles_logic_type_text (int type);
-string styles_logic_subtype_text (int type, int subtype);
+std::string styles_logic_standard_sheet ();
+std::string styles_logic_category_text (std::string category);
+std::string styles_logic_type_text (int type);
+std::string styles_logic_subtype_text (int type, int subtype);
 bool styles_logic_fontsize_is_relevant (int type, int subtype);
 bool styles_logic_italic_bold_underline_smallcaps_are_relevant (int type, int subtype);
 bool styles_logic_italic_bold_underline_smallcaps_are_full (int type, int subtype);
-string styles_logic_off_on_inherit_toggle_text (int value);
+std::string styles_logic_off_on_inherit_toggle_text (int value);
 bool styles_logic_superscript_is_relevant (int type, int subtype);
 bool styles_logic_paragraph_treats_are_relevant (int type, int subtype);
-string styles_logic_alignment_text (int value);
+std::string styles_logic_alignment_text (int value);
 bool styles_logic_columns_are_relevant (int type, int subtype);
 bool styles_logic_color_is_relevant (int type, int subtype);
 bool styles_logic_print_is_relevant (int type, int subtype);
 int styles_logic_get_userbool1_function (int type, int subtype);
-string styles_logic_get_userbool1_text (int function);
+std::string styles_logic_get_userbool1_text (int function);
 int styles_logic_get_userbool2_function (int type, int subtype);
-string styles_logic_get_userbool2_text (int function);
+std::string styles_logic_get_userbool2_text (int function);
 int styles_logic_get_userbool3_function (int type, int subtype);
-string styles_logic_get_userbool3_text (int function);
+std::string styles_logic_get_userbool3_text (int function);
 int styles_logic_get_userint1_function (int type, int subtype);
-string styles_logic_note_numbering_text (int value);
+std::string styles_logic_note_numbering_text (int value);
 int styles_logic_get_userint2_function (int type, int subtype);
-string styles_logic_note_restart_numbering_text (int value);
-string styles_logic_end_note_position_text (int value);
+std::string styles_logic_note_restart_numbering_text (int value);
+std::string styles_logic_end_note_position_text (int value);
 int styles_logic_get_userint3_function (int type, int subtype);
 int styles_logic_get_userstring1_function (int type, int subtype);
 int styles_logic_get_userstring2_function (int type, int subtype);
