@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -43,17 +43,17 @@
 #include <database/logic.h>
 
 
-mutex sword_logic_installer_mutex;
-bool sword_logic_installing_module = false;
+std::mutex sword_logic_installer_mutex {};
+bool sword_logic_installing_module {false};
 #ifdef HAVE_SWORD
-mutex sword_logic_library_access_mutex;
+std::mutex sword_logic_library_access_mutex {};
 #endif
-mutex sword_logic_diatheke_run_mutex;
+std::mutex sword_logic_diatheke_run_mutex {};
 
 
-string sword_logic_get_path ()
+std::string sword_logic_get_path ()
 {
-  string sword_path = ".";
+  std::string sword_path {"."};
   char * home = getenv ("HOME");
   if (home) sword_path = home;
   sword_path.append ("/.sword/InstallMgr");
@@ -65,15 +65,15 @@ void sword_logic_refresh_module_list ()
 {
   Database_Logs::log ("Refreshing list of SWORD modules");
   
-  string out_err;
+  std::string out_err {};
   
   // Initialize SWORD directory structure and configuration.
-  string sword_path = sword_logic_get_path ();
+  std::string sword_path = sword_logic_get_path ();
   filter_url_mkdir (sword_path);
-  string swordconf = "[Install]\n"
+  std::string swordconf = "[Install]\n"
                      "DataPath=" + sword_path + "/\n";
-  filter_url_file_put_contents (filter_url_create_path (sword_path, "sword.conf"), swordconf);
-  string config_files_path = filter_url_create_root_path ("sword");
+  filter_url_file_put_contents (filter_url_create_path ({sword_path, "sword.conf"}), swordconf);
+  std::string config_files_path = filter_url_create_root_path ({"sword"});
   filter_shell_run ("cp -r " + config_files_path + "/locales.d " + sword_path, out_err);
   sword_logic_log (out_err);
   filter_shell_run ("cp -r " + config_files_path + "/mods.d " + sword_path, out_err);
@@ -83,7 +83,7 @@ void sword_logic_refresh_module_list ()
 #ifdef HAVE_SWORD
   sword_logic_installmgr_initialize ();
 #else
-  filter_shell_run ("echo yes | installmgr -init", out_err);
+  filter_shell_run ("installmgr --allow-internet-access-and-risk-tracing-and-jail-or-martyrdom --allow-unverified-tls-peer -init", out_err);
   sword_logic_log (out_err);
 #endif
   
@@ -97,24 +97,24 @@ void sword_logic_refresh_module_list ()
     return;
   }
 #else
-  filter_shell_run ("echo yes | installmgr -sc", out_err);
-  filter_string_replace_between (out_err, "WARNING", "enable? [no]", "");
+  filter_shell_run ("installmgr --allow-internet-access-and-risk-tracing-and-jail-or-martyrdom --allow-unverified-tls-peer -sc", out_err);
+  filter::strings::replace_between (out_err, "WARNING", "enable? [no]", "");
   sword_logic_log (out_err);
 #endif
   
   // List the remote sources.
-  vector <string> remote_sources;
+  std::vector <std::string> remote_sources {};
 #ifdef HAVE_SWORD
   sword_logic_installmgr_list_remote_sources (remote_sources);
 #else
   filter_shell_run ("installmgr -s", out_err);
   sword_logic_log (out_err);
-  vector <string> lines = filter_string_explode (out_err, '\n');
+  std::vector <std::string> lines = filter::strings::explode (out_err, '\n');
   for (auto line : lines) {
-    line = filter_string_trim (line);
-    if (line.find ("[") != string::npos) {
+    line = filter::strings::trim (line);
+    if (line.find ("[") != std::string::npos) {
       line.erase (0, 1);
-      if (line.find ("]") != string::npos) {
+      if (line.find ("]") != std::string::npos) {
         line.erase (line.length () - 1, 1);
         remote_sources.push_back (line);
         Database_Logs::log (line);
@@ -123,67 +123,67 @@ void sword_logic_refresh_module_list ()
   }
 #endif
   
-  vector <string> sword_modules;
+  std::vector <std::string> sword_modules {};
   
-  for (auto remote_source : remote_sources) {
+  for (const auto& remote_source : remote_sources) {
     
 #ifdef HAVE_SWORD
     if (!sword_logic_installmgr_refresh_remote_source (remote_source)) {
       Database_Logs::log ("Error refreshing remote source " + remote_source);
     }
 #else
-    filter_shell_run ("echo yes | installmgr -r \"" + remote_source + "\"", out_err);
-    filter_string_replace_between (out_err, "WARNING", "type yes at the prompt", "");
+    filter_shell_run ("installmgr --allow-internet-access-and-risk-tracing-and-jail-or-martyrdom --allow-unverified-tls-peer -r \"" + remote_source + "\"", out_err);
+    filter::strings::replace_between (out_err, "WARNING", "type yes at the prompt", "");
     sword_logic_log (out_err);
 #endif
 
-    vector <string> modules;
+    std::vector <std::string> modules {};
 #ifdef HAVE_SWORD
     sword_logic_installmgr_list_remote_modules (remote_source, modules);
-    for (auto & module : modules) {
+    for (const auto& module : modules) {
       sword_modules.push_back ("[" + remote_source + "]" + " " + module);
     }
 #else
     filter_shell_run ("installmgr -rl \"" + remote_source + "\"", out_err);
-    lines = filter_string_explode (out_err, '\n');
+    lines = filter::strings::explode (out_err, '\n');
     for (auto line : lines) {
-      line = filter_string_trim (line);
+      line = filter::strings::trim (line);
       if (line.empty ()) continue;
-      if (line.find ("[") == string::npos) continue;
-      if (line.find ("]") == string::npos) continue;
+      if (line.find ("[") == std::string::npos) continue;
+      if (line.find ("]") == std::string::npos) continue;
       modules.push_back ("[" + remote_source + "]" + " " + line);
     }
-    for (auto module : modules) {
+    for (const auto& module : modules) {
       sword_modules.push_back (module);
     }
 #endif
-    Database_Logs::log (remote_source + ": " + convert_to_string (modules.size ()) + " modules");
+    Database_Logs::log (remote_source + ": " + filter::strings::convert_to_string (modules.size ()) + " modules");
   }
   
   // Store the list of remote sources and their modules.
   // It is stored in the client files area.
   // Clients can access it from there too.
-  string path = sword_logic_module_list_path ();
-  filter_url_file_put_contents (path, filter_string_implode (sword_modules, "\n"));
+  std::string path = sword_logic_module_list_path ();
+  filter_url_file_put_contents (path, filter::strings::implode (sword_modules, "\n"));
   
   Database_Logs::log ("Ready refreshing SWORD module list");
 }
 
 
-string sword_logic_module_list_path ()
+std::string sword_logic_module_list_path ()
 {
-  return filter_url_create_root_path (database_logic_databases (), "client", "sword_modules.txt");
+  return filter_url_create_root_path ({database_logic_databases (), "client", "sword_modules.txt"});
 }
 
 
 // Gets the name of the remote source of the $line like this:
 // [CrossWire] *[Shona] (1.1) - Shona Bible
-string sword_logic_get_source (string line)
+std::string sword_logic_get_source (std::string line)
 {
-  if (line.length () < 10) return "";
+  if (line.length () < 10) return std::string();
   line.erase (0, 1);
   size_t pos = line.find ("]");
-  if (pos == string::npos) return "";
+  if (pos == std::string::npos) return std::string();
   line.erase (pos);
   return line;
 }
@@ -191,16 +191,16 @@ string sword_logic_get_source (string line)
 
 // Gets the module name of the $line like this:
 // [CrossWire] *[Shona] (1.1) - Shona Bible
-string sword_logic_get_remote_module (string line)
+std::string sword_logic_get_remote_module (std::string line)
 {
-  if (line.length () < 10) return "";
+  if (line.length () < 10) return std::string();
   line.erase (0, 2);
-  if (line.length () < 10) return "";
+  if (line.length () < 10) return std::string();
   size_t pos = line.find ("[");
-  if (pos == string::npos) return "";
+  if (pos == std::string::npos) return std::string();
   line.erase (0, pos + 1);
   pos = line.find ("]");
-  if (pos == string::npos) return "";
+  if (pos == std::string::npos) return std::string();
   line.erase (pos);
   return line;
 }
@@ -208,13 +208,13 @@ string sword_logic_get_remote_module (string line)
 
 // Gets the module name of the $line like this:
 // [Shona]  (1.1)  - Shona Bible
-string sword_logic_get_installed_module (string line)
+std::string sword_logic_get_installed_module (std::string line)
 {
-  line = filter_string_trim (line);
+  line = filter::strings::trim (line);
   if (line.length () > 10) {
     line.erase (0, 1);
     size_t pos = line.find ("]");
-    if (pos != string::npos) line.erase (pos);
+    if (pos != std::string::npos) line.erase (pos);
   }
   return line;
 }
@@ -222,17 +222,17 @@ string sword_logic_get_installed_module (string line)
 
 // Gets the version number of a module of the $line like this:
 // [Shona]  (1.1)  - Shona Bible
-string sword_logic_get_version (string line)
+std::string sword_logic_get_version (std::string line)
 {
-  line = filter_string_trim (line);
+  line = filter::strings::trim (line);
   if (line.length () > 10) {
     line.erase (0, 3);
   }
   if (line.length () > 10) {
     size_t pos = line.find ("(");
-    if (pos != string::npos) line.erase (0, pos + 1);
+    if (pos != std::string::npos) line.erase (0, pos + 1);
     pos = line.find (")");
-    if (pos != string::npos) line.erase (pos);
+    if (pos != std::string::npos) line.erase (pos);
   }
   return line;
 }
@@ -240,20 +240,20 @@ string sword_logic_get_version (string line)
 
 // Gets the human-readable name of a $line like this:
 // [CrossWire] *[Shona] (1.1) - Shona Bible
-string sword_logic_get_name (string line)
+std::string sword_logic_get_name (std::string line)
 {
-  vector <string> bits = filter_string_explode (line, '-');
+  std::vector <std::string> bits = filter::strings::explode (line, '-');
   if (bits.size () >= 2) {
     bits.erase (bits.begin ());
   }
-  line = filter_string_implode (bits, "-");
-  line = filter_string_trim (line);
+  line = filter::strings::implode (bits, "-");
+  line = filter::strings::trim (line);
   return line;
 }
 
 
 // Schedule SWORD module installation.
-void sword_logic_install_module_schedule (string source, string module)
+void sword_logic_install_module_schedule (const std::string& source, const std::string& module)
 {
   // No source: Done.
   if (source.empty ()) return;
@@ -272,10 +272,10 @@ void sword_logic_install_module_schedule (string source, string module)
 }
 
 
-void sword_logic_install_module (string source_name, string module_name)
+void sword_logic_install_module (const std::string& source_name, const std::string& module_name)
 {
   Database_Logs::log ("Install SWORD module " + module_name + " from source " + source_name);
-  string sword_path = sword_logic_get_path ();
+  std::string sword_path {sword_logic_get_path ()};
 
   // Installation through SWORD InstallMgr does not yet work.
   // When running it from the ~/.sword/InstallMgr directory, it works.
@@ -314,61 +314,65 @@ void sword_logic_install_module (string source_name, string module_name)
   
 #else
   
-  string out_err;
-  filter_shell_run ("cd " + sword_path + "; echo yes | installmgr -ri \"" + source_name + "\" \"" + module_name + "\"", out_err);
+  std::string out_err {};
+  std::string command = "cd " + sword_path + "; installmgr --allow-internet-access-and-risk-tracing-and-jail-or-martyrdom --allow-unverified-tls-peer -ri \"" + source_name + "\" \"" + module_name + "\"";
+  Database_Logs::log (command);
+  filter_shell_run (command, out_err);
   sword_logic_log (out_err);
   
 #endif
 
-  // After the installation is complete, cache some data.
-  // This cached data indicates the last access time for this SWORD module.
-  string url = sword_logic_virtual_url (module_name, 0, 0, 0);
-  database_filebased_cache_put (url, "SWORD");
+  // After the installation is complete, write some temporal some data.
+  // This temporal data indicates the last access time for this SWORD module.
+  {
+    const std::string path = sword_logic_access_tracker (module_name);
+    filter_url_file_put_contents (path, "SWORD");
+  }
 }
 
 
-void sword_logic_uninstall_module (string module)
+void sword_logic_uninstall_module (const std::string& module)
 {
   Database_Logs::log ("Uninstall SWORD module " + module);
-  string out_err;
-  string sword_path = sword_logic_get_path ();
+  std::string out_err;
+  const std::string sword_path {sword_logic_get_path ()};
   filter_shell_run ("cd " + sword_path + "; installmgr -u \"" + module + "\"", out_err);
   sword_logic_log (out_err);
 }
 
 
 // Get available SWORD modules.
-vector <string> sword_logic_get_available ()
+std::vector <std::string> sword_logic_get_available ()
 {
-  string contents = filter_url_file_get_contents (sword_logic_module_list_path ());
-  return filter_string_explode (contents, '\n');
+  const std::string contents = filter_url_file_get_contents (sword_logic_module_list_path ());
+  return filter::strings::explode (contents, '\n');
 }
 
 
 // Get installed SWORD modules.
-vector <string> sword_logic_get_installed ()
+std::vector <std::string> sword_logic_get_installed ()
 {
-  vector <string> modules;
-  string out_err;
-  string sword_path = sword_logic_get_path ();
+  std::vector <std::string> modules {};
+  std::string out_err {};
+  const std::string sword_path {sword_logic_get_path ()};
   filter_shell_run ("cd " + sword_path + "; installmgr -l", out_err);
-  vector <string> lines = filter_string_explode (out_err, '\n');
+  std::vector <std::string> lines = filter::strings::explode (out_err, '\n');
   for (auto line : lines) {
-    line = filter_string_trim (line);
+    line = filter::strings::trim (line);
     if (line.empty ()) continue;
-    if (line.find ("[") == string::npos) continue;
+    if (line.find ("[") == std::string::npos) continue;
     modules.push_back (line);
   }
   return modules;
 }
 
 
-string sword_logic_get_text (string source, string module, int book, int chapter, int verse)
+std::string sword_logic_get_text (const std::string& source, const std::string& module, const int book, const int chapter, const int verse)
 {
 #ifdef HAVE_CLIENT
 
   // The resource name consists of source and module, e.g. [CrossWire][NET].
-  string resource = sword_logic_get_resource_name (source, module);
+  std::string resource = sword_logic_get_resource_name (source, module);
 
   // Client checks for and optionally creates the cache for this SWORD source/module.
   if (!Database_Cache::exists (resource, book)) {
@@ -381,7 +385,7 @@ string sword_logic_get_text (string source, string module, int book, int chapter
   }
 
   // Fetch this SWORD resource from the server.
-  string address = Database_Config_General::getServerAddress ();
+  std::string address = Database_Config_General::getServerAddress ();
   int port = Database_Config_General::getServerPort ();
   if (!client_logic_client_enabled ()) {
     // If the client has not been connected to a cloud instance,
@@ -389,13 +393,13 @@ string sword_logic_get_text (string source, string module, int book, int chapter
     address = demo_address ();
     port = demo_port ();
   }
-  string url = client_logic_url (address, port, sync_resources_url ());
+  std::string url = client_logic_url (address, port, sync_resources_url ());
   url = filter_url_build_http_query (url, "r", resource);
-  url = filter_url_build_http_query (url, "b", convert_to_string (book));
-  url = filter_url_build_http_query (url, "c", convert_to_string (chapter));
-  url = filter_url_build_http_query (url, "v", convert_to_string (verse));
-  string error;
-  string html = filter_url_http_get (url, error, true);
+  url = filter_url_build_http_query (url, "b", filter::strings::convert_to_string (book));
+  url = filter_url_build_http_query (url, "c", filter::strings::convert_to_string (chapter));
+  url = filter_url_build_http_query (url, "v", filter::strings::convert_to_string (verse));
+  std::string error {};
+  std::string html = filter_url_http_get (url, error, true);
   
   // In case of an error, don't cache that error, but let the user see it.
   if (!error.empty ()) return error;
@@ -412,31 +416,44 @@ string sword_logic_get_text (string source, string module, int book, int chapter
   
 #else
 
-  string module_text;
-  bool module_available = false;
+  std::string module_text;
+  bool module_available {false};
 
-  string osis = Database_Books::getOsisFromId (book);
-  string chapter_verse = convert_to_string (chapter) + ":" + convert_to_string (verse);
+  const std::string osis = database::books::get_osis_from_id (static_cast<book_id>(book));
+  const std::string chapter_verse = filter::strings::convert_to_string (chapter) + ":" + filter::strings::convert_to_string (verse);
 
   // See notes on function sword_logic_diatheke
   // for why it is not currently fetching content via a SWORD library call.
   // module_text = sword_logic_diatheke (module, osis, chapter, verse, module_available);
   
   // Running diatheke only works when it runs in the SWORD installation directory.
-  string sword_path = sword_logic_get_path ();
+  const std::string sword_path = sword_logic_get_path ();
   // Running several instances of diatheke simultaneously fails.
   sword_logic_diatheke_run_mutex.lock ();
   // The server fetches the module text as follows:
   // diatheke -b KJV -k Jn 3:16
-  string error;
-  int result = filter_shell_run (sword_path, "diatheke", { "-b", module, "-k", osis, chapter_verse }, &module_text, &error);
+  // To included, run this instead: $ diatheke -b KJV -o n -k Jn 3:16
+  std::vector <std::string> parameters {"-b", module};
+  if (Database_Config_General::getKeepOsisContentInSwordResources ()) {
+    parameters.push_back("-o");
+    parameters.push_back("n");
+  }
+  parameters.push_back("-k");
+  parameters.push_back(osis);
+  parameters.push_back(chapter_verse);
+  std::string error {};
+  const int result = filter_shell_run (sword_path, "diatheke", { "-b", module, "-o", "n", "-k", osis, chapter_verse }, &module_text, &error);
   module_text.append (error);
   sword_logic_diatheke_run_mutex.unlock ();
   if (result != 0) return sword_logic_fetch_failure_text ();
   
-  // Touch the cache so the server knows that the module has been accessed just now and won't uninstall it too soon.
-  string url = sword_logic_virtual_url (module, 0, 0, 0);
-  database_filebased_cache_get (url);
+  // Touch the temporal file
+  // so the server knows that the module has been accessed just now
+  // and won't uninstall it too soon.
+  {
+    const std::string path = sword_logic_access_tracker (module);
+    filter_url_file_put_contents (path, "access");
+  }
 
   // If the module has not been installed, the output of "diatheke" will be empty.
   // If the module was installed, but the requested passage is out of range,
@@ -446,9 +463,9 @@ string sword_logic_get_text (string source, string module, int book, int chapter
   if (!module_available) {
     
     // Check whether the SWORD module exists.
-    vector <string> modules = sword_logic_get_available ();
-    string smodules = filter_string_implode (modules, "");
-    if (smodules.find ("[" + module + "]") != string::npos) {
+    std::vector <std::string> modules {sword_logic_get_available ()};
+    const std::string smodules = filter::strings::implode (modules, std::string());
+    if (smodules.find ("[" + module + "]") != std::string::npos) {
       // Schedule SWORD module installation.
       // (It used to be the case that this function, to get the text,
       // would wait till the SWORD module was installed, and then after installation,
@@ -473,64 +490,62 @@ string sword_logic_get_text (string source, string module, int book, int chapter
 }
 
 
-map <int, string> sword_logic_get_bulk_text (const string & module, int book, int chapter, vector <int> verses)
+std::map <int, std::string> sword_logic_get_bulk_text (const std::string& module, const int book, const int chapter, const std::vector <int>& verses)
 {
   // Touch the cache so the server knows that the module has been accessed and won't uninstall it too soon.
-  string url = sword_logic_virtual_url (module, 0, 0, 0);
-  database_filebased_cache_get (url);
-
-  // The name of the book to pass to diatheke.
-  string osis = Database_Books::getOsisFromId (book);
-  
-  // Signatures that will indicate start and end of verse text.
-  map <int, string> starters, finishers;
-  
-  // The script to run.
-  // It will fetch verse text for all verses in a chapter.
-  // Fetching verse text in bulk reduces the number of fork () calls.
-  vector <string> script;
-  script.push_back ("#!/bin/bash");
-  script.push_back ("cd '" + sword_logic_get_path () + "'");
-  for (auto verse : verses) {
-    string starter = "starter" + convert_to_string (verse) + "starter";
-    script.push_back ("echo " + starter);
-    starters [verse] = starter;
-    string chapter_verse = convert_to_string (chapter) + ":" + convert_to_string (verse);
-    script.push_back ("diatheke -b " + module + " -k " + osis + " " + chapter_verse);
-    string finisher = "finisher" + convert_to_string (verse) + "finisher";
-    script.push_back ("echo " + finisher);
-    finishers [verse] = finisher;
+  {
+    const std::string path = sword_logic_access_tracker (module);
+    filter_url_file_put_contents (path, "bulk");
   }
 
-  // Store the script and make it executable.
-  string script_path = filter_url_create_path (sword_logic_get_path (), "script.sh");
-  filter_url_file_put_contents (script_path, filter_string_implode (script, "\n"));
-  string chmod = "chmod +x " + script_path;
-  int result;
-#ifdef HAVE_CLOUD
-  result = system (chmod.c_str ());
-  (void) result;
-#endif
+  // The name of the book to pass to diatheke.
+  const std::string osis = database::books::get_osis_from_id (static_cast<book_id>(book));
 
-  // Run the script.
-  string out_err;
-  result = filter_shell_run (script_path, out_err);
-  (void) result;
+  // Cannot run more than one "diatheke" per user, so use a mutex for that.
+  sword_logic_diatheke_run_mutex.lock ();
+
+  // Here is how to speed up SWORD text retrieval.
+  // The main point is to not pass just one verse,
+  // but to pass the chapter number without the verse.
+  // So it returns the entire chapter in one go.
+  // One would even be able to pass the book only, so it returns the entire book.
+  // But that would not add much to increasing the speed.
+  // cd ~/.sword/InstallMgr
+  // diatheke -b AB -k Ezra 5:1
+  // diatheke -b AB -k Ezra 5
+  // diatheke -b AB -k Ezra
+  std::string error {};
+  std::string bulk_text {};
+  const int result = filter_shell_run (sword_logic_get_path (), "diatheke", { "-b", module, "-k", osis, filter::strings::convert_to_string (chapter) }, &bulk_text, &error);
+  bulk_text.append (error);
+  if (result != 0) Database_Logs::log (error);
+  // This is how the output would look.
+  // Malachi 3:1: <verse osisID="Mal.3.1">Behold, I send forth My messenger, and he shall survey the way before Me: and the Lord, whom you seek, shall suddenly come into His temple, even the Messenger of the covenant, whom you take pleasure in: behold, He is coming, says the Lord Almighty.
+
+  sword_logic_diatheke_run_mutex.unlock ();
 
   // Resulting verse text.
-  map <int, string> output;
-  
-  for (auto & verse : verses) {
-    string starter = starters [verse];
-    size_t pos1 = out_err.find (starter);
-    string finisher = finishers [verse];
-    size_t pos2 = out_err.find (finisher);
-    if ((pos1 != string::npos) && (pos2 != string::npos)) {
-      pos1 += starter.length ();
-      string text = out_err.substr (pos1, pos2 - pos1);
-      text = sword_logic_clean_verse (module, chapter, verse, text);
-      output [verse] = text;
+  std::map <int, std::string> output {};
+
+  // Iterate over all requested verses to extract the correct content from the chapter.
+  // This works well in general.
+  // It has been seen in a sample module, the "AB", that some verses in the SWORD module were empty.
+  // In case of such verses, there's no content to extract from the chapter.
+  // The cause in such verses is in the module builder.
+  for (const auto verse : verses) {
+    const std::string starter = " " + filter::strings::convert_to_string(chapter) + ":" + filter::strings::convert_to_string(verse) + ":";
+    size_t pos1 = bulk_text.find (starter);
+    if (pos1 == std::string::npos) {
+      //Database_Logs::log("Cannot find starter: |" + starter + "|");
+      continue;
     }
+    const std::string finisher = "\n";
+    size_t pos2 = bulk_text.find (finisher, pos1);
+    if (pos2 == std::string::npos) pos2 = bulk_text.length() + 1;
+    pos1 += starter.length ();
+    std::string text = bulk_text.substr (pos1, pos2 - pos1);
+    text = sword_logic_clean_verse (module, chapter, verse, text);
+    output [verse] = text;
   }
   
   // Done.
@@ -543,31 +558,18 @@ void sword_logic_update_installed_modules ()
 {
   Database_Logs::log ("Updating installed SWORD modules");
 
-  vector <string> available_modules = sword_logic_get_available ();
+  std::vector <std::string> available_modules = sword_logic_get_available ();
 
-  vector <string> installed_modules = sword_logic_get_installed ();
-  for (auto & installed_module : installed_modules) {
-    string module = sword_logic_get_installed_module (installed_module);
-    string installed_version = sword_logic_get_version (installed_module);
-    for (auto & available_module : available_modules) {
+  std::vector <std::string> installed_modules = sword_logic_get_installed ();
+  for (const auto& installed_module : installed_modules) {
+    const std::string module = sword_logic_get_installed_module (installed_module);
+    const std::string installed_version = sword_logic_get_version (installed_module);
+    for (const auto& available_module : available_modules) {
       if (sword_logic_get_remote_module (available_module) == module) {
         if (sword_logic_get_version (available_module) != installed_version) {
-          string source = sword_logic_get_source (available_module);
+          const std::string source = sword_logic_get_source (available_module);
           // Uninstall module.
           sword_logic_uninstall_module (module);
-          // Clear the cache.
-          Database_Versifications database_versifications;
-          vector <int> books = database_versifications.getMaximumBooks ();
-          for (auto & book : books) {
-            vector <int> chapters = database_versifications.getMaximumChapters (book);
-            for (auto & chapter : chapters) {
-              vector <int> verses = database_versifications.getMaximumVerses (book, chapter);
-              for (auto & verse : verses) {
-                string schema = sword_logic_virtual_url (module, book, chapter, verse);
-                database_filebased_cache_remove (schema);
-              }
-            }
-          }
           // Schedule module installation.
           sword_logic_install_module_schedule (source, module);
         }
@@ -585,11 +587,11 @@ void sword_logic_trim_modules ()
 {
 #ifndef HAVE_CLIENT
   Database_Logs::log ("Trimming the installed SWORD modules");
-  vector <string> modules = sword_logic_get_installed ();
+  const std::vector <std::string> modules = sword_logic_get_installed ();
   for (auto module : modules) {
     module = sword_logic_get_installed_module (module);
-    string url = sword_logic_virtual_url (module, 0, 0, 0);
-    if (!database_filebased_cache_exists (url)) {
+    const std::string path = sword_logic_access_tracker (module);
+    if (!file_or_dir_exists (path)) {
       sword_logic_uninstall_module (module);
     }
   }
@@ -600,7 +602,7 @@ void sword_logic_trim_modules ()
 
 // Text saying that the Cloud will install the requested SWORD module.
 // Client knows not to cache this.
-string sword_logic_installing_module_text ()
+std::string sword_logic_installing_module_text ()
 {
   return "The requested SWORD module is not yet installed. Bibledit Cloud will install it shortly. Please check back after a few minutes.";
 }
@@ -608,31 +610,31 @@ string sword_logic_installing_module_text ()
 
 // Text stating fetch failure.
 // Client knows not to cache this.
-string sword_logic_fetch_failure_text ()
+std::string sword_logic_fetch_failure_text ()
 {
   return "Failure to fetch SWORD content.";
 }
 
 
-// The virtual URL for caching purposes.
-string sword_logic_virtual_url (const string & module, int book, int chapter, int verse)
+// Tracker for accessing the SWORD module.
+std::string sword_logic_access_tracker (const std::string& module)
 {
-  string url = "sword_" + module + "_" + convert_to_string (book) + "_chapter_" + convert_to_string (chapter) + "_verse_" + convert_to_string (verse);
-  return url;
+  const std::string path = filter_url_create_root_path ({filter_url_temp_dir (), "sword_access_tracker_" + module});
+  return path;
 }
 
 
 // The functions runs a scheduled module installation.
 // The purpose of this function is that only one module installation occurs at a time,
 // rather than simultaneously installing modules, which clogs the system.
-void sword_logic_run_scheduled_module_install (string source, string module)
+void sword_logic_run_scheduled_module_install (const std::string& source, const std::string& module)
 {
   // If a module is being installed,
   // and a call is made for another module installation,
   // re-schedule this module installation to postpone it,
   // till after this one is ready.
   sword_logic_installer_mutex.lock ();
-  bool installing = sword_logic_installing_module;
+  const bool installing = sword_logic_installing_module;
   sword_logic_installer_mutex.unlock ();
   if (installing) {
     sword_logic_install_module_schedule (source, module);
@@ -645,10 +647,10 @@ void sword_logic_run_scheduled_module_install (string source, string module)
   sword_logic_installer_mutex.unlock ();
 
   // Run the installer if the module is not yet installed.
-  vector <string> modules = sword_logic_get_installed ();
+  const std::vector <std::string> modules {sword_logic_get_installed ()};
   bool already_installed = false;
-  for (auto & installed_module : modules) {
-    if (installed_module.find ("[" + module + "]") != string::npos) {
+  for (const auto& installed_module : modules) {
+    if (installed_module.find ("[" + module + "]") != std::string::npos) {
       already_installed = true;
     }
   }
@@ -713,9 +715,8 @@ bool sword_logic_installmgr_synchronize_configuration_with_master ()
 }
 
 
-void sword_logic_installmgr_list_remote_sources (vector <string> & sources)
+void sword_logic_installmgr_list_remote_sources ([[maybe_unused]] const std::vector <std::string>& sources)
 {
-  (void) sources;
 #ifdef HAVE_SWORD
   sword::SWBuf baseDir = sword_logic_get_path ().c_str ();
   
@@ -723,7 +724,7 @@ void sword_logic_installmgr_list_remote_sources (vector <string> & sources)
   installMgr->setUserDisclaimerConfirmed (true);
   
   for (sword::InstallSourceMap::iterator it = installMgr->sources.begin(); it != installMgr->sources.end(); it++) {
-    string caption (it->second->caption);
+    const std::string caption (it->second->caption);
     sources.push_back (caption);
     /*
     string description;
@@ -743,9 +744,8 @@ void sword_logic_installmgr_list_remote_sources (vector <string> & sources)
 }
 
 
-bool sword_logic_installmgr_refresh_remote_source (string name)
+bool sword_logic_installmgr_refresh_remote_source ([[maybe_unused]] const std::string& name)
 {
-  (void) name;
   bool success = true;
 #ifdef HAVE_SWORD
   sword::SWBuf baseDir = sword_logic_get_path ().c_str ();
@@ -768,10 +768,9 @@ bool sword_logic_installmgr_refresh_remote_source (string name)
 }
 
 
-void sword_logic_installmgr_list_remote_modules (string source_name, vector <string> & modules)
+void sword_logic_installmgr_list_remote_modules ([[maybe_unused]] const std::string& source_name,
+                                                 [[maybe_unused]] std::vector <std::string>& modules)
 {
-  (void) source_name;
-  (void) modules;
 #ifdef HAVE_SWORD
   sword::SWMgr *mgr = new sword::SWMgr();
   
@@ -829,14 +828,13 @@ void sword_logic_installmgr_list_remote_modules (string source_name, vector <str
 
  And this crash takes down the whole Bibledit Cloud instance.
  */
-string sword_logic_diatheke (const string & module_name, const string& osis, int chapter, int verse, bool & available)
+std::string sword_logic_diatheke ([[maybe_unused]] const std::string& module_name,
+                                  [[maybe_unused]] const std::string& osis,
+                                  [[maybe_unused]] int chapter,
+                                  [[maybe_unused]] int verse,
+                                  [[maybe_unused]] bool& available)
 {
-  (void) module_name;
-  (void) osis;
-  (void) chapter;
-  (void) verse;
-  (void) available;
-  string rendering;
+  std::string rendering {};
 #ifdef HAVE_SWORD
   // When accessing the SWORD library from multiple threads simultaneously, the library often crashes.
   // A mutex fixes this behaviour.
@@ -867,7 +865,7 @@ string sword_logic_diatheke (const string & module_name, const string& osis, int
   sword::SWModule *module = manager.getModule (module_name.c_str ());
   available = module;
   if (module) {
-    string key = osis + " " + convert_to_string (chapter) + ":" + convert_to_string (verse);
+    string key = osis + " " + filter::strings::convert_to_string (chapter) + ":" + filter::strings::convert_to_string (verse);
     module->setKey (key.c_str ());
     rendering = module->renderText();
   }
@@ -878,41 +876,45 @@ string sword_logic_diatheke (const string & module_name, const string& osis, int
 }
 
 
-void sword_logic_log (string message)
+void sword_logic_log (std::string message)
 {
   // Remove less comely stuff, warnings, confusing information.
-  message = filter_string_str_replace ("-=+*", "", message);
-  message = filter_string_str_replace ("WARNING", "", message);
-  message = filter_string_str_replace ("*+=-", "", message);
-  message = filter_string_str_replace ("enable?", "", message);
-  message = filter_string_str_replace ("[no]", "", message);
+  message = filter::strings::replace ("-=+*", "", message);
+  message = filter::strings::replace ("WARNING", "", message);
+  message = filter::strings::replace ("*+=-", "", message);
+  message = filter::strings::replace ("enable?", "", message);
+  message = filter::strings::replace ("[no]", "", message);
   // Clean message up.
-  message = filter_string_trim (message);
+  message = filter::strings::trim (message);
   // Record in the journal.
   Database_Logs::log (message);
 }
 
 
-string sword_logic_clean_verse (const string & module, int chapter, int verse, string text)
+std::string sword_logic_clean_verse (const std::string& module, int chapter, int verse, std::string text)
 {
-  // Remove any OSIS elements.
-  filter_string_replace_between (text, "<", ">", "");
+  // Remove any OSIS elements or make those elements displayable.
+  if (Database_Config_General::getKeepOsisContentInSwordResources ()) {
+    text = filter::strings::escape_special_xml_characters (text);
+  } else {
+    filter::strings::replace_between (text, "<", ">", "");
+  }
   
   // Remove the passage name that diatheke adds.
   // A reliable signature for this is the chapter and verse plus subsequent colon.
-  string chapter_verse = convert_to_string (chapter) + ":" + convert_to_string (verse);
+  const std::string chapter_verse = filter::strings::convert_to_string (chapter) + ":" + filter::strings::convert_to_string (verse);
   size_t pos = text.find (" " + chapter_verse + ":");
-  if (pos != string::npos) {
+  if (pos != std::string::npos) {
     pos += 2;
     pos += chapter_verse.size ();
     text.erase (0, pos);
   }
   
   // Remove the module name that diatheke adds.
-  text = filter_string_str_replace ("(" + module + ")", "", text);
+  text = filter::strings::replace ("(" + module + ")", "", text);
   
   // Clean whitespace away.
-  text = filter_string_trim (text);
+  text = filter::strings::trim (text);
 
   // Done.
   return text;
@@ -920,7 +922,7 @@ string sword_logic_clean_verse (const string & module, int chapter, int verse, s
 
 
 // Take the SWORD $source and SWORD $module and form it into a canonical resource name.
-string sword_logic_get_resource_name (const string & source, const string & module)
+std::string sword_logic_get_resource_name (const std::string& source, const std::string& module)
 {
   return "[" + source + "][" + module + "]";
 }
