@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,5 +21,5 @@
 
 #include <config/libraries.h>
 
-string sync_files_url ();
-string sync_files (void * webserver_request);
+std::string sync_files_url ();
+std::string sync_files (void * webserver_request);
