@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <database/users.h>
 #include <sync/logic.h>
 #include <user/logic.h>
+using namespace std;
 
 
 string sync_setup_url ()
@@ -35,7 +36,7 @@ string sync_setup_url ()
 
 string sync_setup (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Sync_Logic sync_logic = Sync_Logic (webserver_request);
   
   if (!sync_logic.security_okay ()) {
@@ -47,7 +48,7 @@ string sync_setup (void * webserver_request)
   string page;
   
   string username = request->query ["user"];
-  username = hex2bin (username);
+  username = filter::strings::hex2bin (username);
   string password = request->query ["pass"];
 
   // Check the credentials of the client.
@@ -57,7 +58,7 @@ string sync_setup (void * webserver_request)
       // Check brute force attack mitigation.
       if (user_logic_login_failure_check_okay ()) {
         // Return the level to the client.
-        return convert_to_string (request->database_users ()->get_level (username));
+        return filter::strings::convert_to_string (request->database_users ()->get_level (username));
       }
     }
   }
