@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -41,15 +41,15 @@ void tasks_logic_queue (string command, vector <string> parameters)
   lines.push_back (command);
   lines.insert (lines.end(), parameters.begin(), parameters.end());
   // The filename to write to contains seconds and microseconds.
-  string seconds = convert_to_string (filter::date::seconds_since_epoch ());
-  string time = seconds + filter_string_fill (convert_to_string (filter::date::numerical_microseconds ()), 8, '0');
+  string seconds = filter::strings::convert_to_string (filter::date::seconds_since_epoch ());
+  string time = seconds + filter::strings::fill (filter::strings::convert_to_string (filter::date::numerical_microseconds ()), 8, '0');
   string file = filter_url_create_path ({tasks_logic_folder (), time});
   // On Windows the microtime is not fine enough.
   // This leads to one task overwriting a previous one in case it is queued immediately after.
   // Deal with that problem here: Ensure the filename is unique.
   file = filter_url_unique_path (file);
   // Save it.
-  command = filter_string_implode (lines, "\n");
+  command = filter::strings::implode (lines, "\n");
   filter_url_file_put_contents (file, command);
 }
 
@@ -68,7 +68,7 @@ bool tasks_logic_queued (string command, vector <string> parameters)
   for (auto & file : files) {
     // Read the task's contents.
     string contents = filter_url_file_get_contents (filter_url_create_path ({tasks_logic_folder (), file}));
-    vector <string> lines = filter_string_explode (contents, '\n');
+    vector <string> lines = filter::strings::explode (contents, '\n');
     if (lines.empty ()) return false;
     // Look for a match.
     bool match = true;
