@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -83,12 +83,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define TRIMCACHES "trimcaches"
 #define EXPORT2NMT "export2nmt"
 #define CREATEEMPTYBIBLE "createemptybible"
-#define DELETEINDONESIANFREEUSER "deleteindonesianfreeuser"
-#define EXPIREINDONESIANFREEUSERS "expireindonesianfreeusers"
 #define IMPORTBIBLEIMAGES "importbibleimages"
+#define GETGOOGLEACCESSTOKEN "getgoogleaccesstoken"
 
 
-string tasks_logic_folder ();
-void tasks_logic_queue (string command, vector <string> parameters = { });
-bool tasks_logic_queued (string command, vector <string> parameters = { });
+std::string tasks_logic_folder ();
+void tasks_logic_queue (std::string command, std::vector <std::string> parameters = { });
+bool tasks_logic_queued (std::string command, std::vector <std::string> parameters = { });
 
