@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2023 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -237,16 +237,6 @@ void timer_index ()
       }
 #endif
 
-      
-#ifdef HAVE_CLOUD
-      // In the free Indonesian Cloud configuration, expire free users after so many days.
-      if (config::logic::indonesian_cloud_free ()) {
-        if ((hour == 3) && (minute == 10)) {
-          tasks_logic_queue (EXPIREINDONESIANFREEUSERS);
-        }
-      }
-#endif
-
 	
 #ifdef HAVE_CLOUD
       // Update SWORD modules and other web resources once a week.
