@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,5 +21,5 @@
 
 #include <config/libraries.h>
 
-vector <string> versification_logic_names ();
-string versification_logic_data (string name);
+std::vector <std::string> versification_logic_names ();
+std::string versification_logic_data (std::string name);
