@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ string versification_system (void * webserver_request)
   Database_Versifications database_versifications = Database_Versifications();
 
   string name = request->query["name"];
-  view.set_variable ("name", escape_special_xml_characters (name));
+  view.set_variable ("name", filter::strings::escape_special_xml_characters (name));
 
   if (request->post.count ("submit")) {
     string data = request->post["data"];
@@ -80,11 +80,11 @@ string versification_system (void * webserver_request)
     string bookname = database::books::get_english_from_id (static_cast<book_id>(book));
     data.push_back ("<tr>");
     data.push_back ("<td>" + bookname + "</td>");
-    data.push_back ("<td>" + convert_to_string (chapter) + "</td>");
-    data.push_back ("<td>" + convert_to_string (verse) + "</td>");
+    data.push_back ("<td>" + filter::strings::convert_to_string (chapter) + "</td>");
+    data.push_back ("<td>" + filter::strings::convert_to_string (verse) + "</td>");
     data.push_back ("</tr>");
   }
-  view.set_variable ("data", filter_string_implode (data, "\n"));
+  view.set_variable ("data", filter::strings::implode (data, "\n"));
 
   string output = database_versifications.output (name);
   view.set_variable ("output", output);
