@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_VERSIFICATION_SYSTEM_H
-#define INCLUDED_VERSIFICATION_SYSTEM_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string versification_system_url ();
+std::string versification_system_url ();
 bool versification_system_acl (void * webserver_request);
-string versification_system (void * webserver_request);
-
-
-#endif
+std::string versification_system (void * webserver_request);
