@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,9 +17,7 @@
  */
 
 
-#ifndef INCLUDED_WEBSERVER_IO_H
-#define INCLUDED_WEBSERVER_IO_H
-
+#pragma once
 
 #include <config.h>
 #ifdef HAVE_WINDOWS
@@ -28,7 +26,6 @@
 #include <sys/socket.h>
 #endif
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -38,6 +35,3 @@ int mybind (int socket, const struct sockaddr *address, unsigned int address_len
 #ifdef __cplusplus
 }
 #endif
-
-
-#endif
