@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2023 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_WORKBENCH_INDEX_H
-#define INCLUDED_WORKBENCH_INDEX_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string workspace_index_url ();
+std::string workspace_index_url ();
 bool workspace_index_acl (void * webserver_request);
-string workspace_index (void * webserver_request);
-
-
-#endif
+std::string workspace_index (void * webserver_request);
